@@ -1,20 +1,23 @@
-/*
- * InfoNode.h
- *
- *  Created on: 19 feb 2015
- *      Author: Daniel
- */
+/*******************************************************************************
+ Infomap software package for multi-level network clustering
+ Copyright (c) 2013, 2014 Daniel Edler, Anton Eriksson, Martin Rosvall
 
-#ifndef SRC_CLUSTERING_INFONODE_H_
-#define SRC_CLUSTERING_INFONODE_H_
+ This file is part of the Infomap software package.
+ See file LICENSE_AGPLv3.txt for full license details.
+ For more information, see <http://www.mapequation.org>
+ ******************************************************************************/
+
+#ifndef INFONODE_H_
+#define INFONODE_H_
 
 #include "FlowData.h"
 #include "InfoEdge.h"
-#include "infomapIterators.h"
-#include "treeIterators.h"
-#include "../utils/iterators.h"
-#include "../utils/exceptions.h"
+#include "iterators/infomapIterators.h"
+#include "iterators/treeIterators.h"
+#include "iterators/IterWrapper.h"
 #include "../utils/MetaCollection.h"
+
+#include <stdexcept>
 #include <memory>
 #include <iostream>
 #include <vector>
@@ -26,8 +29,6 @@ class InfomapBase;
 
 class InfoNode {
 public:
-  using EdgeType = Edge<InfoNode>;
-
   using child_iterator = ChildIterator<InfoNode*>;
   using const_child_iterator = ChildIterator<InfoNode const*>;
   using infomap_child_iterator = InfomapChildIterator<InfoNode*>;
@@ -44,8 +45,8 @@ public:
   using post_depth_first_iterator = DepthFirstIterator<InfoNode*, false>;
   using const_post_depth_first_iterator = DepthFirstIterator<InfoNode const*, false>;
 
-  using edge_iterator = std::vector<EdgeType*>::iterator;
-  using const_edge_iterator = std::vector<EdgeType*>::const_iterator;
+  using edge_iterator = std::vector<InfoEdge*>::iterator;
+  using const_edge_iterator = std::vector<InfoEdge*>::const_iterator;
 
   using edge_iterator_wrapper = IterWrapper<edge_iterator>;
   using const_edge_iterator_wrapper = IterWrapper<const_edge_iterator>;
@@ -62,10 +63,9 @@ public:
 public:
   FlowData data;
   unsigned int index = 0; // Temporary index used in finding best module
-  //	unsigned int originalIndex = 0; // Index in the original network (for leaf nodes)
-  /*const*/ unsigned int stateId = 0; // Unique state node id for the leaf nodes
-  /*const*/ unsigned int physicalId = 0; // Physical id equals stateId for first order networks, otherwise can be non-unique
-  /*const*/ unsigned int layerId = 0; // Layer id for multilayer networks
+  unsigned int stateId = 0; // Unique state node id for the leaf nodes
+  unsigned int physicalId = 0; // Physical id equals stateId for first order networks, otherwise can be non-unique
+  unsigned int layerId = 0; // Layer id for multilayer networks
   std::vector<int> metaData; // Categorical value for each meta data dimension
 
   InfoNode* owner = nullptr; // Infomap owner (if this is an Infomap root)
@@ -76,24 +76,21 @@ public:
   InfoNode* lastChild = nullptr;
   InfoNode* collapsedFirstChild = nullptr;
   InfoNode* collapsedLastChild = nullptr;
-  double codelength = 0.0; //TODO: Better design for hierarchical stuff!?
+  double codelength = 0.0; // TODO: Better design for hierarchical stuff!?
   bool dirty = false;
 
   std::vector<PhysData> physicalNodes;
   MetaCollection metaCollection; // For modules
   std::vector<unsigned int> stateNodes; // For physically aggregated nodes
 
-protected:
-  //	SubStructure m_subStructure;
-  // std::unique_ptr<InfomapBase> m_infomap;
+private:
   unsigned int m_childDegree = 0;
   bool m_childrenChanged = false;
   unsigned int m_numLeafMembers = 0;
 
-  std::vector<EdgeType*> m_outEdges;
-  std::vector<EdgeType*> m_inEdges;
+  std::vector<InfoEdge*> m_outEdges;
+  std::vector<InfoEdge*> m_inEdges;
 
-  // std::unique_ptr<InfomapBase> m_infomap;
   InfomapBase* m_infomap = nullptr;
 
 public:
@@ -110,7 +107,7 @@ public:
   InfoNode(const FlowData& flowData, unsigned int stateId, unsigned int physicalId, unsigned int layerId)
       : data(flowData), stateId(stateId), physicalId(physicalId), layerId(layerId) {};
 
-  InfoNode() {};
+  InfoNode() = default;
 
   InfoNode(const InfoNode& other)
       : data(other.data),
@@ -131,11 +128,9 @@ public:
         metaCollection(other.metaCollection),
         m_childDegree(other.m_childDegree),
         m_childrenChanged(other.m_childrenChanged),
-        m_numLeafMembers(other.m_numLeafMembers) {}
-
-
-  ~InfoNode();
+        m_numLeafMembers(other.m_numLeafMembers) { }
 
+  ~InfoNode() noexcept;
 
   InfoNode& operator=(const InfoNode& other)
   {
@@ -163,7 +158,7 @@ public:
 
   // ---------------------------- Getters ----------------------------
 
-  unsigned int getMetaData(unsigned int dimension = 0)
+  unsigned int getMetaData(unsigned int dimension = 0) noexcept
   {
     if (dimension >= metaData.size()) {
       return 0;
@@ -177,256 +172,126 @@ public:
 
   InfomapBase& setInfomap(InfomapBase*);
 
-  InfoNode* getInfomapRoot();
+  InfoNode* getInfomapRoot() noexcept;
 
-  InfoNode const* getInfomapRoot() const;
+  InfoNode const* getInfomapRoot() const noexcept;
 
   /**
    * Dispose the Infomap instance if it exists
    * @return true if an existing Infomap instance was deleted
    */
-  bool disposeInfomap();
+  bool disposeInfomap() noexcept;
 
   /**
    * Number of physical nodes in memory nodes
    */
-  unsigned int numPhysicalNodes() const { return physicalNodes.size(); }
+  unsigned int numPhysicalNodes() const noexcept { return physicalNodes.size(); }
 
   // ---------------------------- Tree iterators ----------------------------
 
   // Default iteration on children
-  child_iterator begin()
-  {
-    return child_iterator(this);
-  }
+  child_iterator begin() noexcept { return { this }; }
 
-  child_iterator end()
-  {
-    return child_iterator(nullptr);
-  }
+  child_iterator end() noexcept { return { nullptr }; }
 
-  const_child_iterator begin() const
-  {
-    return const_child_iterator(this);
-  }
+  const_child_iterator begin() const noexcept { return { this }; }
 
-  const_child_iterator end() const
-  {
-    return const_child_iterator(nullptr);
-  }
+  const_child_iterator end() const noexcept { return { nullptr }; }
 
-  child_iterator begin_child()
-  {
-    return child_iterator(this);
-  }
+  child_iterator begin_child() noexcept { return { this }; }
 
-  child_iterator end_child()
-  {
-    return child_iterator(nullptr);
-  }
+  child_iterator end_child() noexcept { return { nullptr }; }
 
-  const_child_iterator begin_child() const
-  {
-    return const_child_iterator(this);
-  }
+  const_child_iterator begin_child() const noexcept { return { this }; }
 
-  const_child_iterator end_child() const
-  {
-    return const_child_iterator(nullptr);
-  }
+  const_child_iterator end_child() const noexcept { return { nullptr }; }
 
-  child_iterator_wrapper children()
-  {
-    return child_iterator_wrapper(child_iterator(this), child_iterator(nullptr));
-  }
+  child_iterator_wrapper children() noexcept { return { { this }, { nullptr } }; }
 
-  const_child_iterator_wrapper children() const
-  {
-    return const_child_iterator_wrapper(const_child_iterator(this), const_child_iterator(nullptr));
-  }
+  const_child_iterator_wrapper children() const noexcept { return { { this }, { nullptr } }; }
 
-  infomap_child_iterator_wrapper infomap_children()
-  {
-    return infomap_child_iterator_wrapper(infomap_child_iterator(this), infomap_child_iterator(nullptr));
-  }
+  infomap_child_iterator_wrapper infomap_children() noexcept { return { { this }, { nullptr } }; }
 
-  const_infomap_child_iterator_wrapper infomap_children() const
-  {
-    return const_infomap_child_iterator_wrapper(const_infomap_child_iterator(this), const_infomap_child_iterator(nullptr));
-  }
+  const_infomap_child_iterator_wrapper infomap_children() const noexcept { return { { this }, { nullptr } }; }
 
-  // InfomapLeafIterator begin_leaf()
-  // { return InfomapLeafIterator(this); }
+  post_depth_first_iterator begin_post_depth_first() noexcept { return { this }; }
 
-  // InfomapLeafIterator end_leaf()
-  // { return InfomapLeafIterator(nullptr); }
+  leaf_node_iterator begin_leaf_nodes() noexcept { return { this }; }
 
-  post_depth_first_iterator begin_post_depth_first()
-  {
-    return post_depth_first_iterator(this);
-  }
+  leaf_module_iterator begin_leaf_modules() noexcept { return { this }; }
 
-  leaf_node_iterator begin_leaf_nodes()
-  {
-    return leaf_node_iterator(this);
-  }
+  tree_iterator begin_tree(unsigned int maxClusterLevel = std::numeric_limits<unsigned int>::max()) noexcept { return { this, static_cast<int>(maxClusterLevel) }; }
 
-  leaf_module_iterator begin_leaf_modules()
-  {
-    return leaf_module_iterator(this);
-  }
+  tree_iterator end_tree() noexcept { return { nullptr }; }
 
-  tree_iterator begin_tree(unsigned int maxClusterLevel = std::numeric_limits<unsigned int>::max())
-  {
-    return tree_iterator(this, maxClusterLevel);
-  }
+  const_tree_iterator begin_tree(unsigned int maxClusterLevel = std::numeric_limits<unsigned int>::max()) const noexcept { return { this, static_cast<int>(maxClusterLevel) }; }
 
-  tree_iterator end_tree()
-  {
-    return tree_iterator(nullptr);
-  }
+  const_tree_iterator end_tree() const noexcept { return { nullptr }; }
 
-  const_tree_iterator begin_tree(unsigned int maxClusterLevel = std::numeric_limits<unsigned int>::max()) const
-  {
-    return const_tree_iterator(this, maxClusterLevel);
-  }
+  infomap_iterator_wrapper infomapTree(unsigned int maxClusterLevel = std::numeric_limits<unsigned int>::max()) noexcept { return { { this, static_cast<int>(maxClusterLevel) }, { nullptr } }; }
 
-  const_tree_iterator end_tree() const
-  {
-    return const_tree_iterator(nullptr);
-  }
-
-  infomap_iterator_wrapper infomapTree(unsigned int maxClusterLevel = std::numeric_limits<unsigned int>::max())
-  {
-    return infomap_iterator_wrapper(tree_iterator(this, maxClusterLevel), tree_iterator(nullptr));
-  }
-
-  const_infomap_iterator_wrapper infomapTree(unsigned int maxClusterLevel = std::numeric_limits<unsigned int>::max()) const
-  {
-    return const_infomap_iterator_wrapper(const_tree_iterator(this, maxClusterLevel), const_tree_iterator(nullptr));
-  }
+  const_infomap_iterator_wrapper infomapTree(unsigned int maxClusterLevel = std::numeric_limits<unsigned int>::max()) const noexcept { return { { this, static_cast<int>(maxClusterLevel) }, { nullptr } }; }
 
   // ---------------------------- Graph iterators ----------------------------
 
-  edge_iterator begin_outEdge()
-  {
-    return m_outEdges.begin();
-  }
+  edge_iterator begin_outEdge() noexcept { return m_outEdges.begin(); }
 
-  edge_iterator end_outEdge()
-  {
-    return m_outEdges.end();
-  }
+  edge_iterator end_outEdge() noexcept { return m_outEdges.end(); }
 
-  edge_iterator begin_inEdge()
-  {
-    return m_inEdges.begin();
-  }
+  edge_iterator begin_inEdge() noexcept { return m_inEdges.begin(); }
 
-  edge_iterator end_inEdge()
-  {
-    return m_inEdges.end();
-  }
+  edge_iterator end_inEdge() noexcept { return m_inEdges.end(); }
 
-  //	inout_edge_iterator begin_inoutEdge()
-  //	{ return inout_edge_iterator(begin_inEdge(), end_inEdge(), begin_outEdge()); }
-  //
-  //	inout_edge_iterator	end_inoutEdge()
-  //	{ return inout_edge_iterator(end_outEdge()); }
+  edge_iterator_wrapper outEdges() noexcept { return { m_outEdges }; }
 
-  edge_iterator_wrapper outEdges()
-  {
-    return edge_iterator_wrapper(m_outEdges);
-  }
-
-  edge_iterator_wrapper inEdges()
-  {
-    return edge_iterator_wrapper(m_inEdges);
-  }
+  edge_iterator_wrapper inEdges() noexcept { return { m_inEdges }; }
 
   // ---------------------------- Capacity ----------------------------
 
-  unsigned int childDegree() const;
+  unsigned int childDegree() const noexcept { return m_childDegree; }
 
-  bool isLeaf() const;
-  bool isLeafModule() const;
-  bool isRoot() const;
+  bool isLeaf() const noexcept { return firstChild == nullptr; }
 
-  unsigned int depth() const;
+  // TODO: Safe to assume all children are leaves if first child is leaf?
+  bool isLeafModule() const noexcept { return m_infomap == nullptr && firstChild != nullptr && firstChild->firstChild == nullptr; }
 
-  unsigned int firstDepthBelow() const;
+  bool isRoot() const noexcept { return parent == nullptr; }
 
-  unsigned int numLeafMembers()
-  {
-    return m_numLeafMembers;
-  }
+  unsigned int depth() const noexcept;
 
-  bool isDangling()
-  {
-    return m_outEdges.empty();
-  }
+  unsigned int firstDepthBelow() const noexcept;
 
-  unsigned int outDegree()
-  {
-    return m_outEdges.size();
-  }
+  unsigned int numLeafMembers() const noexcept { return m_numLeafMembers; }
 
-  unsigned int inDegree()
-  {
-    return m_inEdges.size();
-  }
+  bool isDangling() const noexcept { return m_outEdges.empty(); }
 
-  unsigned int degree()
-  {
-    return outDegree() + inDegree();
-  }
+  unsigned int outDegree() const noexcept { return m_outEdges.size(); }
 
-  //	InfomapBase* getSubInfomap()
-  //	{ return m_subStructure.subInfomap.get(); }
-  //
-  //	const InfomapBase* getSubInfomap() const
-  //	{ return m_subStructure.subInfomap.get(); }
-  //
-  //	SubStructure& getSubStructure()
-  //	{ return m_subStructure; }
-  //
-  //	const SubStructure& getSubStructure() const
-  //	{ return m_subStructure; }
+  unsigned int inDegree() const noexcept { return m_inEdges.size(); }
+
+  unsigned int degree() const noexcept { return outDegree() + inDegree(); }
 
   // ---------------------------- Order ----------------------------
-  bool isFirst() const
-  {
-    return !parent || parent->firstChild == this;
-  }
+  bool isFirst() const noexcept { return !parent || parent->firstChild == this; }
 
-  bool isLast() const
-  {
-    return !parent || parent->lastChild == this;
-  }
+  bool isLast() const noexcept { return !parent || parent->lastChild == this; }
 
-  unsigned int childIndex() const;
+  unsigned int childIndex() const noexcept;
 
   // Generate 1-based tree path
-  std::vector<unsigned int> calculatePath() const;
+  std::vector<unsigned int> calculatePath() const noexcept;
 
-  unsigned int infomapChildDegree() const;
+  unsigned int infomapChildDegree() const noexcept;
 
-  unsigned int id() const { return stateId; }
+  unsigned int id() const noexcept { return stateId; }
 
   // ---------------------------- Operators ----------------------------
 
-  bool operator==(const InfoNode& rhs) const
-  {
-    return this == &rhs;
-  }
+  bool operator==(const InfoNode& rhs) const noexcept { return this == &rhs; }
 
-  bool operator!=(const InfoNode& rhs) const
-  {
-    return this != &rhs;
-  }
+  bool operator!=(const InfoNode& rhs) const noexcept { return this != &rhs; }
 
-
-  friend std::ostream& operator<<(std::ostream& out, const InfoNode& node)
+  friend std::ostream& operator<<(std::ostream& out, const InfoNode& node) noexcept
   {
     if (node.isLeaf())
       out << "[" << node.physicalId << "]";
@@ -440,15 +305,15 @@ public:
   /**
    * Clear a cloned node to initial state
    */
-  void initClean();
+  void initClean() noexcept;
 
-  void sortChildrenOnFlow(bool recurse = true);
+  void sortChildrenOnFlow(bool recurse = true) noexcept;
 
   /**
    * Release the children and store the child pointers for later expansion
    * @return the number of children collapsed
    */
-  unsigned int collapseChildren();
+  unsigned int collapseChildren() noexcept;
 
   /**
    * Expand collapsed children
@@ -459,13 +324,13 @@ public:
   // ------ OLD -----
 
   // After change, set the child degree if known instead of lazily computing it by traversing the linked list
-  void setChildDegree(unsigned int value);
+  void setChildDegree(unsigned int value) noexcept;
 
-  void setNumLeafNodes(unsigned int value);
+  void setNumLeafNodes(unsigned int value) noexcept { m_numLeafMembers = value; }
 
-  void addChild(InfoNode* child);
+  void addChild(InfoNode* child) noexcept;
 
-  void releaseChildren();
+  void releaseChildren() noexcept;
 
   /**
    * If not already having a single child, replace children
@@ -477,36 +342,32 @@ public:
   /**
    * @return 1 if the node is removed, otherwise 0
    */
-  unsigned int replaceWithChildren();
+  unsigned int replaceWithChildren() noexcept;
 
-  void replaceWithChildrenDebug();
-
-  // void storeModulesIn(InfoNode& other);
-  // void restoreModulesTo(InfoNode& other);
+  void replaceWithChildrenDebug() noexcept;
 
   /**
    * @return The number of children removed
    */
-  unsigned int replaceChildrenWithGrandChildren();
+  unsigned int replaceChildrenWithGrandChildren() noexcept;
 
-  void replaceChildrenWithGrandChildrenDebug();
+  void replaceChildrenWithGrandChildrenDebug() noexcept;
 
-  void remove(bool removeChildren);
+  void remove(bool removeChildren) noexcept;
 
-  void deleteChildren();
+  void deleteChildren() noexcept;
 
-  EdgeType* addOutEdge(InfoNode& target, double weight, double flow = 0.0)
+  void addOutEdge(InfoNode& target, double weight, double flow = 0.0) noexcept
   {
-    EdgeType* edge = new EdgeType(*this, target, weight, flow);
+    auto* edge = new InfoEdge(*this, target, weight, flow);
     m_outEdges.push_back(edge);
     target.m_inEdges.push_back(edge);
-    return edge;
   }
 
 private:
-  void calcChildDegree();
+  void calcChildDegree() noexcept;
 };
 
 } // namespace infomap
 
-#endif /* SRC_CLUSTERING_INFONODE_H_ */
+#endif // INFONODE_H_
