@@ -1,19 +1,23 @@
-/*
- * InfomapBase.h
- *
- *  Created on: 23 feb 2015
- *      Author: Daniel
- */
+/*******************************************************************************
+ Infomap software package for multi-level network clustering
+ Copyright (c) 2013, 2014 Daniel Edler, Anton Eriksson, Martin Rosvall
 
-#ifndef SRC_CLUSTERING_INFOMAPBASE_H_
-#define SRC_CLUSTERING_INFOMAPBASE_H_
+ This file is part of the Infomap software package.
+ See file LICENSE_AGPLv3.txt for full license details.
+ For more information, see <http://www.mapequation.org>
+ ******************************************************************************/
+
+#ifndef INFOMAP_BASE_H_
+#define INFOMAP_BASE_H_
 
 #include "InfomapConfig.h"
 #include "InfoEdge.h"
 #include "InfoNode.h"
-#include "InfomapIterator.h"
-#include "ClusterMap.h"
+#include "InfomapOptimizerBase.h"
+#include "iterators/InfomapIterator.h"
+#include "../io/ClusterMap.h"
 #include "../io/Network.h"
+#include "../io/Output.h"
 #include "../utils/Log.h"
 #include "../utils/Date.h"
 #include "../utils/Stopwatch.h"
@@ -28,102 +32,74 @@
 
 namespace infomap {
 
-struct PerLevelStat;
-
 namespace detail {
   class PartitionQueue;
+  struct PerLevelStat;
 } // namespace detail
 
 class InfomapBase : public InfomapConfig<InfomapBase> {
   template <typename Objective>
   friend class InfomapOptimizer;
+  friend class Output;
 
-protected:
-  using EdgeType = Edge<InfoNode>;
+  void initOptimizer(bool forceNoMemory = false);
 
 public:
   using PartitionQueue = detail::PartitionQueue;
+  using PerLevelStat = detail::PerLevelStat;
 
-  InfomapBase() : InfomapConfig<InfomapBase>() { }
+  InfomapBase() : InfomapConfig<InfomapBase>() { initOptimizer(); }
 
-  explicit InfomapBase(const Config& conf) : InfomapConfig<InfomapBase>(conf), m_network(conf) { }
+  explicit InfomapBase(const Config& conf) : InfomapConfig<InfomapBase>(conf), m_network(conf) { initOptimizer(); }
 
-  explicit InfomapBase(const std::string flags) : InfomapConfig<InfomapBase>(flags)
+  explicit InfomapBase(const std::string& flags, bool isCli = false) : InfomapConfig<InfomapBase>(flags, isCli)
   {
+    initOptimizer();
     m_network.setConfig(*this);
     m_initialParameters = m_currentParameters = flags;
   }
 
   virtual ~InfomapBase() = default;
 
-
   // ===================================================
   // Getters
   // ===================================================
 
-  const Network& network() const;
+  Network& network() { return m_network; }
+  const Network& network() const { return m_network; }
 
-  Network& network();
+  InfoNode& root() { return m_root; }
+  const InfoNode& root() const { return m_root; }
 
-  InfoNode& root();
-  const InfoNode& root() const;
+  InfomapIterator iterTree(int maxClusterLevel = 1) { return { &root(), maxClusterLevel }; }
 
-  // InfomapIterator tree(int maxClusterLevel = std::numeric_limits<unsigned int>::max())
-  // { return InfomapIterator(&root(), maxClusterLevel); }
+  InfomapIteratorPhysical iterTreePhysical(int maxClusterLevel = 1) { return { &root(), maxClusterLevel }; }
 
-  InfomapIterator iterTree(int maxClusterLevel = 1)
-  {
-    return InfomapIterator(&root(), maxClusterLevel);
-  }
+  InfomapModuleIterator iterModules(int maxClusterLevel = 1) { return { &root(), maxClusterLevel }; }
 
-  InfomapIteratorPhysical iterTreePhysical(int maxClusterLevel = 1)
-  {
-    return InfomapIteratorPhysical(&root(), maxClusterLevel);
-  }
+  InfomapLeafModuleIterator iterLeafModules(int maxClusterLevel = 1) { return { &root(), maxClusterLevel }; }
 
-  InfomapModuleIterator iterModules(int maxClusterLevel = 1)
-  {
-    return InfomapModuleIterator(&root(), maxClusterLevel);
-  }
+  InfomapLeafIterator iterLeafNodes(int maxClusterLevel = 1) { return { &root(), maxClusterLevel }; }
 
-  InfomapLeafModuleIterator iterLeafModules(int maxClusterLevel = 1)
-  {
-    return InfomapLeafModuleIterator(&root(), maxClusterLevel);
-  }
+  InfomapLeafIteratorPhysical iterLeafNodesPhysical(int maxClusterLevel = 1) { return { &root(), maxClusterLevel }; }
 
-  InfomapLeafIterator iterLeafNodes(int maxClusterLevel = 1)
-  {
-    return InfomapLeafIterator(&root(), maxClusterLevel);
-  }
+  InfomapIterator begin(int maxClusterLevel = 1) { return { &root(), maxClusterLevel }; }
 
-  InfomapLeafIteratorPhysical iterLeafNodesPhysical(int maxClusterLevel = 1)
-  {
-    return InfomapLeafIteratorPhysical(&root(), maxClusterLevel);
-  }
+  InfomapIterator end() { return InfomapIterator(nullptr); }
 
-  InfomapIterator begin(int maxClusterLevel = 1)
-  {
-    return InfomapIterator(&root(), maxClusterLevel);
-  }
+  unsigned int numLeafNodes() const { return m_leafNodes.size(); }
 
-  InfomapIterator end()
-  {
-    return InfomapIterator(nullptr);
-  }
+  const std::vector<InfoNode*>& leafNodes() const { return m_leafNodes; }
 
-  unsigned int numLeafNodes() const;
+  unsigned int numTopModules() const { return m_root.childDegree(); }
 
-  const std::vector<InfoNode*>& leafNodes() const;
+  unsigned int numActiveModules() const { return m_optimizer->numActiveModules(); }
 
-  unsigned int numTopModules() const;
+  unsigned int numNonTrivialTopModules() const { return m_numNonTrivialTopModules; }
 
-  virtual unsigned int numActiveModules() const = 0;
+  bool haveModules() const { return !m_root.isLeaf() && !m_root.firstChild->isLeaf(); }
 
-  unsigned int numNonTrivialTopModules() const;
-
-  bool haveModules() const;
-
-  bool haveNonTrivialModules() const;
+  bool haveNonTrivialModules() const { return numNonTrivialTopModules() > 0; }
 
   /**
    * Number of node levels below the root in current Infomap instance, 1 if no modules
@@ -135,19 +111,19 @@ public:
    */
   unsigned int maxTreeDepth() const;
 
-  virtual double getCodelength() const = 0;
+  double getCodelength() const { return m_optimizer->getCodelength(); }
 
-  virtual double getMetaCodelength(bool unweighted = false) const { return 0.0; }
+  double getMetaCodelength(bool unweighted = false) const { return m_optimizer->getMetaCodelength(unweighted); }
 
-  virtual double codelength() const { return m_hierarchicalCodelength; }
+  double codelength() const { return m_hierarchicalCodelength; }
 
   const std::vector<double>& codelengths() const { return m_codelengths; }
 
-  virtual double getIndexCodelength() const = 0;
+  double getIndexCodelength() const { return m_optimizer->getIndexCodelength(); }
 
-  virtual double getModuleCodelength() const = 0; // m_hierarchicalCodelength - getIndexCodelength()
+  double getModuleCodelength() const { return m_hierarchicalCodelength - m_optimizer->getIndexCodelength(); }
 
-  double getHierarchicalCodelength() const;
+  double getHierarchicalCodelength() const { return m_hierarchicalCodelength; }
 
   double getOneLevelCodelength() const { return m_oneLevelCodelength; }
 
@@ -158,35 +134,60 @@ public:
   }
 
   bool isFullNetwork() const { return m_isMain && m_aggregationLevel == 0; }
-  bool isFirstLoop() { return m_tuneIterationIndex == 0 && isFullNetwork(); }
+  bool isFirstLoop() const { return m_tuneIterationIndex == 0 && isFullNetwork(); }
 
-  // virtual InfomapBase& getInfomap(InfoNode& node);
+  InfomapBase* getNewInfomapInstance() const { return new InfomapBase(getConfig()); }
+  InfomapBase* getNewInfomapInstanceWithoutMemory() const
+  {
+    auto im = new InfomapBase();
+    im->initOptimizer(true);
+    return im;
+  }
 
-  virtual InfomapBase* getNewInfomapInstance() const = 0;
-  virtual InfomapBase* getNewInfomapInstanceWithoutMemory() const = 0;
+  InfomapBase& getSubInfomap(InfoNode& node) const
+  {
+    return node.setInfomap(getNewInfomapInstance())
+        .setIsMain(false)
+        .setSubLevel(m_subLevel + 1)
+        .setNonMainConfig(*this);
+  }
 
-  InfomapBase& getSubInfomap(InfoNode& node);
-  InfomapBase& getSuperInfomap(InfoNode& node);
+  InfomapBase& getSuperInfomap(InfoNode& node) const
+  {
+    return node.setInfomap(getNewInfomapInstanceWithoutMemory())
+        .setIsMain(false)
+        .setSubLevel(m_subLevel + SUPER_LEVEL_ADDITION)
+        .setNonMainConfig(*this);
+  }
 
   /**
    * Only the main infomap reads an external cluster file if exist
    */
-  InfomapBase& setIsMain(bool isMain);
-  InfomapBase& setSubLevel(unsigned int level);
+  InfomapBase& setIsMain(bool isMain)
+  {
+    m_isMain = isMain;
+    return *this;
+  }
 
-  bool isTopLevel() const;
-  bool isSuperLevelOnTopLevel() const;
-  bool isMainInfomap() const;
+  InfomapBase& setSubLevel(unsigned int level)
+  {
+    m_subLevel = level;
+    return *this;
+  }
 
-  bool haveHardPartition() const;
+  bool isTopLevel() const { return (m_subLevel & (SUPER_LEVEL_ADDITION - 1)) == 0; }
+  bool isSuperLevelOnTopLevel() const { return m_subLevel == SUPER_LEVEL_ADDITION; }
+  bool isMainInfomap() const { return m_isMain; }
 
-  std::vector<InfoNode*>& activeNetwork() const;
+  bool haveHardPartition() const { return !m_originalLeafNodes.empty(); }
+
+  std::vector<InfoNode*>& activeNetwork() const { return *m_activeNetwork; }
 
   // ===================================================
   // IO
   // ===================================================
 
-  virtual std::ostream& toString(std::ostream& out) const;
+  std::ostream& toString(std::ostream& out) const { return m_optimizer->toString(out); }
 
   const std::map<unsigned int, unsigned int>& getInitialPartition() const { return m_initialPartition; }
 
@@ -196,15 +197,19 @@ public:
 
   double calcEntropyRate();
 
-  InfomapBase& setInitialPartition(const std::map<unsigned int, unsigned int>& moduleIds);
+  InfomapBase& setInitialPartition(const std::map<unsigned int, unsigned int>& moduleIds)
+  {
+    m_initialPartition = moduleIds;
+    return *this;
+  }
 
   // ===================================================
   // Run
   // ===================================================
 
-  virtual void run(std::string parameters = "");
+  void run(const std::string& parameters = "");
 
-  virtual void run(Network& network);
+  void run(Network& network);
 
   // ===================================================
   // Run: *
@@ -213,9 +218,8 @@ public:
   InfomapBase& initNetwork(Network& network);
   InfomapBase& initNetwork(InfoNode& parent, bool asSuperNetwork = false);
 
-
   void generateSubNetwork(Network& network);
-  virtual void generateSubNetwork(InfoNode& parent);
+  void generateSubNetwork(InfoNode& parent);
 
   /**
    * Init categorical meta data on all nodes from a file with the following format:
@@ -227,7 +231,7 @@ public:
    * 5 3
    *
    */
-  InfomapBase& initMetaData(std::string metaDataFile);
+  InfomapBase& initMetaData(const std::string& metaDataFile);
 
   /**
    * Provide an initial partition of the network.
@@ -237,7 +241,7 @@ public:
    * effective network size during the optimization phase but the hard partitions are
    * after that replaced by the original nodes.
    */
-  InfomapBase& initPartition(std::string clusterDataFile, bool hard = false, const Network* network = nullptr);
+  InfomapBase& initPartition(const std::string& clusterDataFile, bool hard = false, const Network* network = nullptr);
 
   /**
    * Provide an initial partition of the network.
@@ -273,24 +277,29 @@ public:
    */
   InfomapBase& initTree(const NodePaths& tree);
 
-  virtual void init();
+  void init();
 
-  virtual void runPartition();
+  void runPartition()
+  {
+    if (twoLevel)
+      partition();
+    else
+      hierarchicalPartition();
+  }
 
-  virtual void restoreHardPartition();
+  void restoreHardPartition();
 
-  void sortTreeOnFlow();
+  void sortTreeOnFlow() { root().sortChildrenOnFlow(); }
 
-  virtual void writeResult();
+  void writeResult();
 
   // ===================================================
   // runPartition: *
   // ===================================================
 
-  virtual void hierarchicalPartition();
-
-  virtual void partition();
+  void hierarchicalPartition();
 
+  void partition();
 
   // ===================================================
   // runPartition: init: *
@@ -299,56 +308,56 @@ public:
   /**
    * Done in network?
    */
-  virtual void initEnterExitFlow();
+  void initEnterExitFlow();
 
-  virtual void aggregateFlowValuesFromLeafToRoot();
+  void aggregateFlowValuesFromLeafToRoot();
 
   // Init terms that is constant for the whole network
-  virtual void initTree() = 0;
+  void initTree() { return m_optimizer->initTree(); }
 
-  virtual void initNetwork() = 0;
+  void initNetwork() { return m_optimizer->initNetwork(); }
 
-  virtual void initSuperNetwork() = 0;
+  void initSuperNetwork() { return m_optimizer->initSuperNetwork(); }
 
-  virtual double calcCodelength(const InfoNode& parent) const = 0;
+  double calcCodelength(const InfoNode& parent) const { return m_optimizer->calcCodelength(parent); }
 
   /**
    * Calculate and store codelength on all modules in the tree
    * @param includeRoot Also calculate the codelength on the root node
    * @return the hierarchical codelength
    */
-  virtual double calcCodelengthOnTree(bool includeRoot = true);
-
-  /**
-   * Partition layer by layer and
-   */
-  // virtual void preClusterMultilayerNetwork();
-
+  double calcCodelengthOnTree(bool includeRoot = true);
 
   // ===================================================
   // Run: Partition: *
   // ===================================================
 
-  virtual void setActiveNetworkFromLeafs();
+  void setActiveNetworkFromLeafs() { m_activeNetwork = &m_leafNodes; }
 
-  virtual void setActiveNetworkFromChildrenOfRoot();
+  void setActiveNetworkFromChildrenOfRoot();
 
-  virtual void initPartition() = 0;
+  void initPartition() { return m_optimizer->initPartition(); }
 
-  virtual void findTopModulesRepeatedly(unsigned int maxLevels);
+  void findTopModulesRepeatedly(unsigned int maxLevels);
 
-  virtual unsigned int fineTune();
+  unsigned int fineTune();
 
-  virtual unsigned int coarseTune();
+  unsigned int coarseTune();
 
   /**
    * Return the number of effective core loops, i.e. not the last if not at coreLoopLimit
    */
-  virtual unsigned int optimizeActiveNetwork() = 0;
+  unsigned int optimizeActiveNetwork() { return m_optimizer->optimizeActiveNetwork(); }
 
-  virtual void moveActiveNodesToPredefinedModules(std::vector<unsigned int>& modules) = 0;
+  void moveActiveNodesToPredefinedModules(std::vector<unsigned int>& modules)
+  {
+    return m_optimizer->moveActiveNodesToPredefinedModules(modules);
+  }
 
-  virtual void consolidateModules(bool replaceExistingModules = true) = 0;
+  void consolidateModules(bool replaceExistingModules = true)
+  {
+    return m_optimizer->consolidateModules(replaceExistingModules);
+  }
 
   void calculateNumNonTrivialTopModules();
 
@@ -361,8 +370,10 @@ public:
   /**
    * Return true if restored to consolidated optimization state
    */
-  virtual bool restoreConsolidatedOptimizationPointIfNoImprovement(bool forceRestore = false) = 0;
-
+  bool restoreConsolidatedOptimizationPointIfNoImprovement(bool forceRestore = false)
+  {
+    return m_optimizer->restoreConsolidatedOptimizationPointIfNoImprovement(forceRestore);
+  }
 
   // ===================================================
   // Run: Hierarchical Partition: *
@@ -374,24 +385,24 @@ public:
    * @param levelLimit The maximum number of super module levels allowed
    * @return number of levels created
    */
-  virtual unsigned int findHierarchicalSuperModules(unsigned int superLevelLimit = std::numeric_limits<unsigned int>::max());
+  unsigned int findHierarchicalSuperModules(unsigned int superLevelLimit = std::numeric_limits<unsigned int>::max());
 
   /**
    * Find super modules fast by merge and consolidate top modules iteratively
    * @param levelLimit The maximum number of super module levels allowed
    * @return number of levels created
    */
-  virtual unsigned int findHierarchicalSuperModulesFast(unsigned int superLevelLimit = std::numeric_limits<unsigned int>::max());
+  unsigned int findHierarchicalSuperModulesFast(unsigned int superLevelLimit = std::numeric_limits<unsigned int>::max());
 
-  virtual void transformNodeFlowToEnterFlow(InfoNode& parent);
+  void transformNodeFlowToEnterFlow(InfoNode& parent);
 
-  virtual void resetFlowOnModules();
+  void resetFlowOnModules();
 
-  virtual unsigned int removeModules();
+  unsigned int removeModules();
 
-  virtual unsigned int removeSubModules(bool recalculateCodelengthOnTree);
+  unsigned int removeSubModules(bool recalculateCodelengthOnTree);
 
-  virtual unsigned int recursivePartition();
+  unsigned int recursivePartition();
 
   void queueTopModules(PartitionQueue& partitionQueue);
 
@@ -403,8 +414,6 @@ public:
   // Output: *
   // ===================================================
 
-  std::string getOutputFileHeader(bool states = false);
-
   /**
    * Write tree to a .tree file.
    * @param filename the filename for the output file. If empty, use default
@@ -412,7 +421,7 @@ public:
    * @param states if memory network, print the state-level network without merging physical nodes within modules
    * @return the filename written to
    */
-  std::string writeTree(std::string filename = "", bool states = false);
+  std::string writeTree(const std::string& filename = "", bool states = false) { return Output::writeTree(*this, filename, states); }
 
   /**
    * Write flow tree to a .ftree file.
@@ -423,7 +432,7 @@ public:
    * @param states if memory network, print the state-level network without merging physical nodes within modules
    * @return the filename written to
    */
-  std::string writeFlowTree(std::string filename = "", bool states = false);
+  std::string writeFlowTree(const std::string& filename = "", bool states = false) { return Output::writeFlowTree(*this, filename, states); }
 
   /**
    * Write Newick tree to a .tre file.
@@ -432,11 +441,11 @@ public:
    * @param states if memory network, print the state-level network without merging physical nodes within modules
    * @return the filename written to
    */
-  std::string writeNewickTree(std::string filename = "", bool states = false);
+  std::string writeNewickTree(const std::string& filename = "", bool states = false) { return Output::writeNewickTree(*this, filename, states); }
 
-  std::string writeJsonTree(std::string filename = "", bool states = false, bool writeLinks = false);
+  std::string writeJsonTree(const std::string& filename = "", bool states = false, bool writeLinks = false) { return Output::writeJsonTree(*this, filename, states, writeLinks); }
 
-  std::string writeCsvTree(std::string filename = "", bool states = false);
+  std::string writeCsvTree(const std::string& filename = "", bool states = false) { return Output::writeCsvTree(*this, filename, states); }
 
   /**
    * Write tree to a .clu file.
@@ -448,7 +457,7 @@ public:
    * Value -1 will give the module index for the lowest level, i.e. the finest modular structure.
    * @return the filename written to
    */
-  std::string writeClu(std::string filename = "", bool states = false, int moduleIndexLevel = 1);
+  std::string writeClu(const std::string& filename = "", bool states = false, int moduleIndexLevel = 1) { return Output::writeClu(*this, filename, states, moduleIndexLevel); }
 
   /**
    * Print per level statistics
@@ -456,7 +465,7 @@ public:
    */
   unsigned int printPerLevelCodelength(std::ostream& out);
 
-  void aggregatePerLevelCodelength(std::vector<PerLevelStat>& perLevelStat, unsigned int level = 0);
+  void aggregatePerLevelCodelength(std::vector<PerLevelStat>& perLevelStat, unsigned int level = 0) { aggregatePerLevelCodelength(root(), perLevelStat, level); }
 
   void aggregatePerLevelCodelength(InfoNode& parent, std::vector<PerLevelStat>& perLevelStat, unsigned int level);
 
@@ -464,46 +473,13 @@ public:
   // Debug: *
   // ===================================================
 
-  virtual void printDebug() { }
+  void printDebug() { return m_optimizer->printDebug(); }
 
   // ===================================================
   // Members
   // ===================================================
 
 protected:
-  virtual void initOptimizer(bool forceNoMemory = false) = 0;
-
-  /**
-   * Write tree to output stream
-   * @param states, write state-level tree, else aggregate physical nodes within modules
-   */
-  void writeTree(std::ostream& outStream, bool states = false);
-
-  /**
-   * Write tree links to output stream
-   */
-  void writeTreeLinks(std::ostream& outStream, bool states = false);
-
-  /**
-   * Write Newick tree to output stream
-   * @param states, write state-level tree, else aggregate physical nodes within modules
-   */
-  void writeNewickTree(std::ostream& outStream, bool states = false);
-
-  /**
-   * Write JSON tree to output stream
-   * @param states, write state-level tree, else aggregate physical nodes within modules
-   */
-  void writeJsonTree(std::ostream& outStream, bool states = false, bool writeLinks = false);
-
-  /**
-   * Write CSV tree to output stream
-   * @param states, write state-level tree, else aggregate physical nodes within modules
-   */
-  void writeCsvTree(std::ostream& outStream, bool states = false);
-
-  std::map<std::string, std::map<std::pair<unsigned int, unsigned int>, double>> aggregateModuleLinks(bool states = false);
-
   InfoNode m_root;
   std::vector<InfoNode*> m_leafNodes;
   std::vector<InfoNode*> m_moduleNodes;
@@ -534,32 +510,43 @@ protected:
   Date m_startDate;
   Date m_endDate;
   Stopwatch m_elapsedTime = Stopwatch(false);
-  std::string m_initialParameters = "";
-  std::string m_currentParameters = "";
+  std::string m_initialParameters;
+  std::string m_currentParameters;
+
+  std::unique_ptr<InfomapOptimizerBase> m_optimizer;
 };
 
-
-struct PerLevelStat {
-  double codelength() const { return indexLength + leafLength; }
-
-  unsigned int numNodes() const { return numModules + numLeafNodes; }
-
-  unsigned int numModules = 0;
-  unsigned int numLeafNodes = 0;
-  double indexLength = 0.0;
-  double leafLength = 0.0;
-};
-
-
 namespace detail {
 
+  struct PerLevelStat {
+    double codelength() const { return indexLength + leafLength; }
+
+    unsigned int numNodes() const { return numModules + numLeafNodes; }
+
+    unsigned int numModules = 0;
+    unsigned int numLeafNodes = 0;
+    double indexLength = 0.0;
+    double leafLength = 0.0;
+  };
+
   class PartitionQueue {
     using PendingModule = InfoNode*;
 
+    std::deque<PendingModule> m_queue;
+
   public:
+    unsigned int level = 1;
+    unsigned int numNonTrivialModules = 0;
+    double flow = 0.0;
+    double nonTrivialFlow = 0.0;
+    bool skip = false;
+    double indexCodelength = 0.0; // Consolidated
+    double leafCodelength = 0.0; // Consolidated
+    double moduleCodelength = 0.0; // Left to improve on next level
+
     using size_t = std::deque<PendingModule>::size_type;
 
-    void swap(PartitionQueue& other)
+    void swap(PartitionQueue& other) noexcept
     {
       std::swap(level, other.level);
       std::swap(numNonTrivialModules, other.numNonTrivialModules);
@@ -577,22 +564,10 @@ namespace detail {
     void resize(size_t size) { m_queue.resize(size); }
 
     PendingModule& operator[](size_t i) { return m_queue[i]; }
-
-    unsigned int level = 1;
-    unsigned int numNonTrivialModules = 0;
-    double flow = 0.0;
-    double nonTrivialFlow = 0.0;
-    bool skip = false;
-    double indexCodelength = 0.0; // Consolidated
-    double leafCodelength = 0.0; // Consolidated
-    double moduleCodelength = 0.0; // Left to improve on next level
-
-  private:
-    std::deque<PendingModule> m_queue;
   };
 
 } // namespace detail
 
 } // namespace infomap
 
-#endif /* SRC_CLUSTERING_INFOMAPBASE_H_ */
+#endif // INFOMAP_BASE_H_
