@@ -1,39 +1,21 @@
-/**********************************************************************************
-
+/*******************************************************************************
  Infomap software package for multi-level network clustering
+ Copyright (c) 2013, 2014 Daniel Edler, Anton Eriksson, Martin Rosvall
 
- Copyright (c) 2013, 2014 Daniel Edler, Martin Rosvall
-
+ This file is part of the Infomap software package.
+ See file LICENSE_AGPLv3.txt for full license details.
  For more information, see <http://www.mapequation.org>
+ ******************************************************************************/
 
+#ifndef STATE_NETWORK_H_
+#define STATE_NETWORK_H_
 
- This file is part of Infomap software package.
-
- Infomap software package is free software: you can redistribute it and/or modify
- it under the terms of the GNU Affero General Public License as published by
- the Free Software Foundation, either version 3 of the License, or
- (at your option) any later version.
-
- Infomap software package is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU Affero General Public License for more details.
-
- You should have received a copy of the GNU Affero General Public License
- along with Infomap software package.  If not, see <http://www.gnu.org/licenses/>.
-
-**********************************************************************************/
-
-
-#ifndef _STATENETWORK_H_
-#define _STATENETWORK_H_
-
+#include "../io/Config.h"
 #include <string>
 #include <map>
 #include <utility>
 #include <vector>
 #include <utility>
-#include "../io/Config.h"
 
 namespace infomap {
 
@@ -50,11 +32,11 @@ public:
     double exitFlow = 0.0;
     double teleFlow = 0.0;
 
-    StateNode(unsigned int id = 0) : id(id), physicalId(id) {}
+    StateNode(unsigned int id = 0) : id(id), physicalId(id) { }
 
-    StateNode(unsigned int id, unsigned int physicalId) : id(id), physicalId(physicalId) {}
+    StateNode(unsigned int id, unsigned int physicalId) : id(id), physicalId(physicalId) { }
 
-    StateNode(unsigned int id, unsigned int physicalId, std::string name) : id(id), physicalId(physicalId), name(std::move(name)) {}
+    StateNode(unsigned int id, unsigned int physicalId, std::string name) : id(id), physicalId(physicalId), name(std::move(name)) { }
 
     bool operator==(const StateNode& rhs) const { return id == rhs.id; }
     bool operator!=(const StateNode& rhs) const { return id != rhs.id; }
@@ -64,17 +46,16 @@ public:
   struct PhysNode {
     unsigned int physId = 0;
     double weight = 1.0;
-    PhysNode(unsigned int physId) : physId(physId) {}
-    PhysNode(unsigned int physId, double weight) : physId(physId), weight(weight) {}
-    PhysNode(double weight = 1.0) : weight(weight) {}
+    PhysNode(unsigned int physId) : physId(physId) { }
+    PhysNode(unsigned int physId, double weight) : physId(physId), weight(weight) { }
+    PhysNode(double weight = 1.0) : weight(weight) { }
   };
 
   struct LinkData {
     double weight = 1.0;
     double flow = 0.0;
-    unsigned int count = 0;
 
-    LinkData(double weight = 1.0) : weight(weight) {}
+    LinkData(double weight = 1.0) : weight(weight) { }
 
     LinkData& operator+=(double w)
     {
@@ -88,7 +69,7 @@ public:
         : source(sourceIndex),
           target(targetIndex),
           weight(weight),
-          flow(weight) {}
+          flow(weight) { }
 
     unsigned int source;
     unsigned int target;
@@ -111,10 +92,8 @@ protected:
   bool m_higherOrderInputMethodCalled = false;
   NodeMap m_nodes; // Nodes indexed by state id (equal physical id for first-order networks)
   NodeLinkMap m_nodeLinkMap;
-  unsigned int m_numNodesFound = 0;
   unsigned int m_numStateNodesFound = 0;
   double m_sumNodeWeight = 0.0;
-  unsigned int m_numLinksFound = 0;
   unsigned int m_numLinks = 0;
   double m_sumLinkWeight = 0.0;
   unsigned int m_numSelfLinksFound = 0;
@@ -132,20 +111,21 @@ protected:
   // Bipartite
   unsigned int m_bipartiteStartId = 0;
 
-  // Infomap
-  // InfoNode m_root;
-
 public:
-  StateNetwork() : m_config(Config()) {}
-  StateNetwork(const Config& config) : m_config(config) {}
+  StateNetwork() : m_config(Config()) { }
+  StateNetwork(Config config) : m_config(std::move(config)) { }
   virtual ~StateNetwork() = default;
 
+  StateNetwork(const StateNetwork&) = delete;
+  StateNetwork& operator=(const StateNetwork&) = delete;
+  StateNetwork(StateNetwork&&) = delete;
+  StateNetwork& operator=(StateNetwork&&) = delete;
+
   // Config
   void setConfig(const Config& config) { m_config = config; }
-  const Config& getConfig() { return m_config; }
 
   // Mutators
-  std::pair<NodeMap::iterator, bool> addStateNode(StateNode node);
+  std::pair<NodeMap::iterator, bool> addStateNode(const StateNode& node);
   std::pair<NodeMap::iterator, bool> addStateNode(unsigned int id, unsigned int physId);
   std::pair<NodeMap::iterator, bool> addNode(unsigned int id);
   std::pair<NodeMap::iterator, bool> addNode(unsigned int id, std::string name);
@@ -155,7 +135,7 @@ public:
   PhysNode& addPhysicalNode(unsigned int physId, double weight);
   PhysNode& addPhysicalNode(unsigned int physId, const std::string& name);
   PhysNode& addPhysicalNode(unsigned int physId, double weight, const std::string& name);
-  std::pair<std::map<unsigned int, std::string>::iterator, bool> addName(unsigned int id, std::string);
+  std::pair<std::map<unsigned int, std::string>::iterator, bool> addName(unsigned int id, const std::string&);
   bool addLink(unsigned int sourceId, unsigned int targetId, double weight = 1.0);
   bool addLink(unsigned int sourceId, unsigned int targetId, unsigned long weight);
 
@@ -187,7 +167,6 @@ public:
   double sumNodeWeight() const { return m_sumNodeWeight; }
   const NodeLinkMap& nodeLinkMap() const { return m_nodeLinkMap; }
   NodeLinkMap& nodeLinkMap() { return m_nodeLinkMap; }
-  // const LinkMap& links() const { return m_links; }
   unsigned int numLinks() const { return m_numLinks; }
   double sumLinkWeight() const { return m_sumLinkWeight; }
   unsigned int numSelfLinks() const { return m_numSelfLinks; }
@@ -195,11 +174,9 @@ public:
   // Use convention of counting self-links only once, treating them as directed
   double sumWeightedDegree() const { return 2 * sumLinkWeight() - (m_config.isUndirectedFlow() ? sumSelfLinkWeight() : 0); }
   unsigned int sumDegree() const { return 2 * numLinks() - (m_config.isUndirectedFlow() ? numSelfLinks() : 0); }
-  // const std::map<unsigned int, double>& outWeights() const { return m_outWeights; }
   std::map<unsigned int, double>& outWeights() { return m_outWeights; }
   std::map<unsigned int, std::string>& names() { return m_names; }
   const std::map<unsigned int, std::string>& names() const { return m_names; }
-  // std::string getName(unsigned int physId);
 
   bool haveDirectedInput() const { return m_haveDirectedInput; }
   bool haveMemoryInput() const { return m_haveMemoryInput; }
@@ -212,7 +189,7 @@ public:
   /**
    * Write state network to file.
    */
-  void writeStateNetwork(std::string filename) const;
+  void writeStateNetwork(const std::string& filename) const;
 
   /**
    * Write state network as first-order Pajek network, where
@@ -220,7 +197,7 @@ public:
    * For a non-memory input, the state nodes are equivalent to
    * physical nodes.
    */
-  void writePajekNetwork(std::string filename, bool printFlow = false) const;
+  void writePajekNetwork(const std::string& filename, bool printFlow = false) const;
 
 protected:
   std::pair<NodeMap::iterator, bool> addStateNodeWithAutogeneratedId(unsigned int physId);
@@ -230,4 +207,4 @@ protected:
 
 } // namespace infomap
 
-#endif /* _STATENETWORK_H_ */
+#endif // STATE_NETWORK_H_
