@@ -1,32 +1,14 @@
-/**********************************************************************************
-
+/*******************************************************************************
  Infomap software package for multi-level network clustering
+ Copyright (c) 2013, 2014 Daniel Edler, Anton Eriksson, Martin Rosvall
 
- Copyright (c) 2013, 2014 Daniel Edler, Martin Rosvall
- 
+ This file is part of the Infomap software package.
+ See file LICENSE_AGPLv3.txt for full license details.
  For more information, see <http://www.mapequation.org>
- 
+ ******************************************************************************/
 
- This file is part of Infomap software package.
-
- Infomap software package is free software: you can redistribute it and/or modify
- it under the terms of the GNU Affero General Public License as published by
- the Free Software Foundation, either version 3 of the License, or
- (at your option) any later version.
-
- Infomap software package is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU Affero General Public License for more details.
-
- You should have received a copy of the GNU Affero General Public License
- along with Infomap software package.  If not, see <http://www.gnu.org/licenses/>.
-
-**********************************************************************************/
-
-
-#ifndef FLOWCALCULATOR_H_
-#define FLOWCALCULATOR_H_
+#ifndef FLOW_CALCULATOR_H_
+#define FLOW_CALCULATOR_H_
 
 #include <map>
 #include <vector>
@@ -54,7 +36,7 @@ public:
     FlowCalculator f(network, config);
   }
 
-protected:
+private:
   FlowCalculator(StateNetwork&, const Config&);
 
   using FlowLink = detail::FlowLink;
@@ -91,4 +73,4 @@ protected:
 
 } // namespace infomap
 
-#endif /* FLOWCALCULATOR_H_ */
+#endif // FLOW_CALCULATOR_H_
