@@ -1,14 +1,18 @@
-/*
- * MetaCollection.h
- */
+/*******************************************************************************
+ Infomap software package for multi-level network clustering
+ Copyright (c) 2013, 2014 Daniel Edler, Anton Eriksson, Martin Rosvall
 
-#ifndef _META_COLLECTION_H
-#define _META_COLLECTION_H
+ This file is part of the Infomap software package.
+ See file LICENSE_AGPLv3.txt for full license details.
+ For more information, see <http://www.mapequation.org>
+ ******************************************************************************/
+
+#ifndef META_COLLECTION_H_
+#define META_COLLECTION_H_
 
-#include <ostream>
-// #include <unordered_map>
-#include <map>
 #include "infomath.h"
+#include <ostream>
+#include <map>
 
 namespace infomap {
 
@@ -16,33 +20,19 @@ struct FlowCount {
   FlowCount() = default;
 
   explicit FlowCount(double flow)
-      : flow(flow), count(1) {}
-
-  FlowCount(const FlowCount& other)
-      : flow(other.flow), count(other.count) {}
-
-  FlowCount& operator=(const FlowCount& other)
-  {
-    flow = other.flow;
-    count = other.count;
-    return *this;
-  }
+      : flow(flow), count(1) { }
 
   FlowCount& operator+=(const FlowCount& o)
   {
-    // std::cout << " [[FlowCount " << *this << " += " << o << " --> ";
     flow += o.flow;
     count += o.count;
-    // std::cout << *this << "]] ";
     return *this;
   }
 
   FlowCount& operator+=(double f)
   {
-    // std::cout << " [FlowCount " << *this << " += " << f << " --> ";
     flow += f;
     ++count;
-    // std::cout << *this << "] ";
     return *this;
   }
 
@@ -76,7 +66,6 @@ struct FlowCount {
   unsigned int count = 0;
 };
 
-// using MetaToFlowCount = std::unordered_map<unsigned int, FlowCount>; // metaId -> (flow,count)
 using MetaToFlowCount = std::map<unsigned int, FlowCount>; // metaId -> (flow,count)
 
 class MetaCollection {
@@ -115,15 +104,6 @@ public:
     }
   }
 
-  void remove(unsigned int meta, double flow)
-  {
-    m_total -= flow;
-    auto& metaFlowCount = m_metaToFlowCount[meta];
-    metaFlowCount -= flow;
-    if (metaFlowCount.empty())
-      m_metaToFlowCount.erase(meta);
-  }
-
   void remove(unsigned int meta, const FlowCount& flow)
   {
     m_total -= flow;
@@ -170,4 +150,4 @@ public:
 
 } // namespace infomap
 
-#endif /* _META_COLLECTION_H */
+#endif // META_COLLECTION_H_
