@@ -1,29 +1,11 @@
-/**********************************************************************************
-
+/*******************************************************************************
  Infomap software package for multi-level network clustering
+ Copyright (c) 2013, 2014 Daniel Edler, Anton Eriksson, Martin Rosvall
 
- Copyright (c) 2013, 2014 Daniel Edler, Martin Rosvall
- 
+ This file is part of the Infomap software package.
+ See file LICENSE_AGPLv3.txt for full license details.
  For more information, see <http://www.mapequation.org>
- 
-
- This file is part of Infomap software package.
-
- Infomap software package is free software: you can redistribute it and/or modify
- it under the terms of the GNU Affero General Public License as published by
- the Free Software Foundation, either version 3 of the License, or
- (at your option) any later version.
-
- Infomap software package is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU Affero General Public License for more details.
-
- You should have received a copy of the GNU Affero General Public License
- along with Infomap software package.  If not, see <http://www.gnu.org/licenses/>.
-
-**********************************************************************************/
-
+ ******************************************************************************/
 
 #ifndef RANDOM_H_
 #define RANDOM_H_
@@ -36,16 +18,16 @@
 #include <utility>
 
 namespace infomap {
-typedef std::mt19937 RandGen;
-typedef std::uniform_int_distribution<unsigned int> uniform_uint_dist;
-typedef uniform_uint_dist::param_type uniform_param_t;
+using RandGen = std::mt19937;
+using uniform_uint_dist = std::uniform_int_distribution<unsigned int>;
+using uniform_param_t = uniform_uint_dist::param_type;
 
 class Random {
   RandGen m_randGen;
   uniform_uint_dist uniform;
 
 public:
-  Random(unsigned int seed = 123) : m_randGen(seed) {}
+  Random(unsigned int seed = 123) : m_randGen(seed) { }
 
   void seed(unsigned int seedValue)
   {
@@ -58,8 +40,8 @@ public:
   }
 
   /**
-    * Get a random permutation of indices of the size of the input vector
-    */
+   * Get a random permutation of indices of the size of the input vector
+   */
   void getRandomizedIndexVector(std::vector<unsigned int>& randomOrder)
   {
     unsigned int size = randomOrder.size();
@@ -81,7 +63,7 @@ class Random {
   MTRand m_randGen;
 
 public:
-  Random(unsigned int seed = 123) : m_randGen(seed) {}
+  Random(unsigned int seed = 123) : m_randGen(seed) { }
 
   void seed(unsigned int seedValue)
   {
@@ -107,4 +89,4 @@ public:
 
 #endif
 
-#endif /* RANDOM_H_ */
+#endif // RANDOM_H_
