@@ -1,28 +1,11 @@
-/**********************************************************************************
-
+/*******************************************************************************
  Infomap software package for multi-level network clustering
+ Copyright (c) 2013, 2014 Daniel Edler, Anton Eriksson, Martin Rosvall
 
- Copyright (c) 2013, 2014 Daniel Edler, Martin Rosvall
- 
+ This file is part of the Infomap software package.
+ See file LICENSE_AGPLv3.txt for full license details.
  For more information, see <http://www.mapequation.org>
- 
-
- This file is part of Infomap software package.
-
- Infomap software package is free software: you can redistribute it and/or modify
- it under the terms of the GNU Affero General Public License as published by
- the Free Software Foundation, either version 3 of the License, or
- (at your option) any later version.
-
- Infomap software package is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU Affero General Public License for more details.
-
- You should have received a copy of the GNU Affero General Public License
- along with Infomap software package.  If not, see <http://www.gnu.org/licenses/>.
-
-**********************************************************************************/
+ ******************************************************************************/
 
 #ifndef STOPWATCH_H_
 #define STOPWATCH_H_
@@ -33,7 +16,6 @@
 
 namespace infomap {
 
-
 class Stopwatch {
 public:
   using Clock = std::chrono::high_resolution_clock;
@@ -91,7 +73,7 @@ public:
 
   friend std::ostream& operator<<(std::ostream& out, const Stopwatch& stopwatch)
   {
-    unsigned int temp = static_cast<unsigned int>(std::floor(stopwatch.getElapsedTimeInMilliSec()));
+    auto temp = static_cast<unsigned int>(std::floor(stopwatch.getElapsedTimeInMilliSec()));
     if (temp > 60'000) {
       if (temp > 3600'000) {
         if (temp > 86'400'000) {
@@ -110,16 +92,6 @@ public:
     return out;
   }
 
-  // static double getElapsedTimeSinceProgramStartInSec()
-  // {
-  // 	return (double)Clock::now() / CLOCKS_PER_SEC;
-  // }
-
-  // static double getElapsedTimeSinceProgramStartInMilliSec()
-  // {
-  // 	return Clock::now() * 1000.0 / CLOCKS_PER_SEC;
-  // }
-
 private:
   TimeType m_start, m_stop;
   bool m_running;
@@ -215,4 +187,4 @@ private:
 
 #endif
 
-#endif /* STOPWATCH_H_ */
+#endif // STOPWATCH_H_
