@@ -1,14 +1,16 @@
-/*
- * MemMapEquation.h
- *
- *  Created on: 4 mar 2015
- *      Author: Daniel
- */
+/*******************************************************************************
+ Infomap software package for multi-level network clustering
+ Copyright (c) 2013, 2014 Daniel Edler, Anton Eriksson, Martin Rosvall
+
+ This file is part of the Infomap software package.
+ See file LICENSE_AGPLv3.txt for full license details.
+ For more information, see <http://www.mapequation.org>
+ ******************************************************************************/
 
 #include "MemMapEquation.h"
 #include "FlowData.h"
 #include "InfoNode.h"
-#include "../utils/Log.h"
+
 #include <vector>
 #include <set>
 #include <map>
@@ -31,28 +33,26 @@ std::ostream& operator<<(std::ostream& out, const MemMapEquation& mapEq)
   return mapEq.print(out);
 }
 
-
 // ===================================================
 // Init
 // ===================================================
 
-void MemMapEquation::init(const Config& config)
+void MemMapEquation::init(const Config& /*config*/)
 {
   Log(3) << "MemMapEquation::init()...\n";
 }
 
-
 void MemMapEquation::initNetwork(InfoNode& root)
 {
   initPhysicalNodes(root);
 }
 
-void MemMapEquation::initSuperNetwork(InfoNode& root)
+void MemMapEquation::initSuperNetwork(InfoNode& /*root*/)
 {
-  //TODO: How use enterFlow instead of flow
+  // TODO: How use enterFlow instead of flow
 }
 
-void MemMapEquation::initSubNetwork(InfoNode& root)
+void MemMapEquation::initSubNetwork(InfoNode& /*root*/)
 {
   //	Base::initSubNetwork(root);
 }
@@ -66,7 +66,6 @@ void MemMapEquation::initPartition(std::vector<InfoNode*>& nodes)
 
 void MemMapEquation::initPhysicalNodes(InfoNode& root)
 {
-  // bool notInitiated = root.firstChild->physicalNodes.empty();
   bool notInitiatedOnRoot = root.physicalNodes.empty();
   if (notInitiatedOnRoot) {
     // Assume leaf nodes directly under the root node
@@ -91,8 +90,7 @@ void MemMapEquation::initPhysicalNodes(InfoNode& root)
 
     for (const auto& physNode : physicalNodes) {
       unsigned int zeroBasedIndex = !toZeroBasedIndex.empty() ? toZeroBasedIndex[physNode.first] : (physNode.first - minPhysicalId);
-      root.physicalNodes.push_back(PhysData(zeroBasedIndex, physNode.second));
-      // Log() << "(" << zeroBasedIndex << ", " << node.data.flow << "), length: " << node.physicalNodes.size() << "\n";
+      root.physicalNodes.emplace_back(zeroBasedIndex, physNode.second);
     }
   }
   auto firstLeafIt = root.begin_leaf_nodes();
@@ -123,12 +121,8 @@ void MemMapEquation::initPhysicalNodes(InfoNode& root)
 
     for (auto it(root.begin_leaf_nodes()); !it.isEnd(); ++it) {
       InfoNode& node = *it;
-      // Log() << "Leaf node " << node.stateId << " (phys " << node.physicalId << ") physicalNodes: ";
-      // unsigned int zeroBasedIndex = toZeroBasedIndex[node.physicalId];
-      // unsigned int zeroBasedIndex = getPhysIndex[node.physicalId];
       unsigned int zeroBasedIndex = !toZeroBasedIndex.empty() ? toZeroBasedIndex[node.physicalId] : (node.physicalId - minPhysicalId);
-      node.physicalNodes.push_back(PhysData(zeroBasedIndex, node.data.flow));
-      // Log() << "(" << zeroBasedIndex << ", " << node.data.flow << "), length: " << node.physicalNodes.size() << "\n";
+      node.physicalNodes.emplace_back(zeroBasedIndex, node.data.flow);
     }
 
     // If leaf nodes was not directly under root, make sure leaf modules have
@@ -143,7 +137,7 @@ void MemMapEquation::initPhysicalNodes(InfoNode& root)
           }
         }
         for (auto& physFlow : physToFlow) {
-          module.physicalNodes.push_back(PhysData(physFlow.first, physFlow.second));
+          module.physicalNodes.emplace_back(physFlow.first, physFlow.second);
         }
       }
     }
@@ -153,7 +147,6 @@ void MemMapEquation::initPhysicalNodes(InfoNode& root)
       // new sub-network
       Log(3) << "MemMapEquation::initPhysicalNodesOnSubNetwork()...\n";
       std::set<unsigned int> setOfPhysicalNodes;
-      // std::cout << "_*!|!*_";
       unsigned int maxPhysNodeIndex = 0;
       unsigned int minPhysNodeIndex = std::numeric_limits<unsigned int>::max();
 
@@ -196,7 +189,7 @@ void MemMapEquation::initPhysicalNodes(InfoNode& root)
           }
         }
         for (auto& physFlow : physToFlow) {
-          module.physicalNodes.push_back(PhysData(physFlow.first, physFlow.second));
+          module.physicalNodes.emplace_back(physFlow.first, physFlow.second);
         }
       }
     }
@@ -222,7 +215,6 @@ void MemMapEquation::initPartitionOfPhysicalNodes(std::vector<InfoNode*>& nodes)
   m_memoryContributionsAdded = false;
 }
 
-
 // ===================================================
 // Codelength
 // ===================================================
@@ -241,8 +233,8 @@ void MemMapEquation::calculateNodeFlow_log_nodeFlow()
   nodeFlow_log_nodeFlow = 0.0;
   for (unsigned int i = 0; i < m_numPhysicalNodes; ++i) {
     const ModuleToMemNodes& moduleToMemNodes = m_physToModuleToMemNodes[i];
-    for (ModuleToMemNodes::const_iterator modToMemIt(moduleToMemNodes.begin()); modToMemIt != moduleToMemNodes.end(); ++modToMemIt)
-      nodeFlow_log_nodeFlow += infomath::plogp(modToMemIt->second.sumFlow);
+    for (const auto& moduleToMemNode : moduleToMemNodes)
+      nodeFlow_log_nodeFlow += infomath::plogp(moduleToMemNode.second.sumFlow);
   }
 }
 
@@ -252,17 +244,17 @@ double MemMapEquation::calcCodelength(const InfoNode& parent) const
     return calcCodelengthOnModuleOfLeafNodes(parent);
   }
   // Use first-order model on index codebook
-  return MapEquation::calcCodelengthOnModuleOfModules(parent);
+  return Base::calcCodelengthOnModuleOfModules(parent);
 }
 
 double MemMapEquation::calcCodelengthOnModuleOfLeafNodes(const InfoNode& parent) const
 {
   if (parent.numPhysicalNodes() == 0) {
-    return MapEquation::calcCodelength(parent); // Infomap root node
+    return Base::calcCodelength(parent); // Infomap root node
   }
 
-  //TODO: For ordinary networks, flow should be used instead of enter flow
-  // for leaf nodes, what about memory networks? sumFlowFromM2Node vs sumEnterFlowFromM2Node?
+  // TODO: For ordinary networks, flow should be used instead of enter flow
+  //  for leaf nodes, what about memory networks? sumFlowFromM2Node vs sumEnterFlowFromM2Node?
   double parentFlow = parent.data.flow;
   double parentExit = parent.data.exitFlow;
   double totalParentFlow = parentFlow + parentExit;
@@ -282,8 +274,8 @@ double MemMapEquation::calcCodelengthOnModuleOfLeafNodes(const InfoNode& parent)
 }
 
 void MemMapEquation::addMemoryContributions(InfoNode& current,
-                                            DeltaFlowDataType& oldModuleDelta,
-                                            VectorMap<DeltaFlowDataType>& moduleDeltaFlow)
+                                            MemDeltaFlow& oldModuleDelta,
+                                            VectorMap<MemDeltaFlow>& moduleDeltaFlow)
 {
   // Overlapping modules
   /*
@@ -299,9 +291,9 @@ void MemMapEquation::addMemoryContributions(InfoNode& current,
   for (unsigned int i = 0; i < numPhysicalNodes; ++i) {
     PhysData& physData = physicalNodes[i];
     ModuleToMemNodes& moduleToMemNodes = m_physToModuleToMemNodes[physData.physNodeIndex];
-    for (ModuleToMemNodes::iterator overlapIt(moduleToMemNodes.begin()); overlapIt != moduleToMemNodes.end(); ++overlapIt) {
-      unsigned int moduleIndex = overlapIt->first;
-      MemNodeSet& memNodeSet = overlapIt->second;
+    for (const auto& moduleToMemNode : moduleToMemNodes) {
+      unsigned int moduleIndex = moduleToMemNode.first;
+      auto& memNodeSet = moduleToMemNode.second;
       if (moduleIndex == current.index) // From where the multiple assigned node is moved
       {
         double oldPhysFlow = memNodeSet.sumFlow;
@@ -313,25 +305,19 @@ void MemMapEquation::addMemoryContributions(InfoNode& current,
         double oldPhysFlow = memNodeSet.sumFlow;
         double newPhysFlow = memNodeSet.sumFlow + physData.sumFlowFromM2Node;
 
-        // DeltaFlowDataType& otherDeltaFlow = moduleDeltaFlow[moduleIndex];
-        // otherDeltaFlow.module = moduleIndex; // Make sure module index is correct if created new module link
-        // otherDeltaFlow.sumDeltaPlogpPhysFlow = infomath::plogp(newPhysFlow) - infomath::plogp(oldPhysFlow);
-        // otherDeltaFlow.sumPlogpPhysFlow = infomath::plogp(physData.sumFlowFromM2Node);
-        // ++otherDeltaFlow.count;
         double sumDeltaPlogpPhysFlow = infomath::plogp(newPhysFlow) - infomath::plogp(oldPhysFlow);
         double sumPlogpPhysFlow = infomath::plogp(physData.sumFlowFromM2Node);
-        moduleDeltaFlow.add(moduleIndex, DeltaFlowDataType(moduleIndex, 0.0, 0.0, sumDeltaPlogpPhysFlow, sumPlogpPhysFlow));
+        moduleDeltaFlow.add(moduleIndex, MemDeltaFlow(moduleIndex, 0.0, 0.0, sumDeltaPlogpPhysFlow, sumPlogpPhysFlow));
       }
     }
   }
   m_memoryContributionsAdded = true;
 }
 
-
 double MemMapEquation::getDeltaCodelengthOnMovingNode(InfoNode& current,
-                                                      DeltaFlowDataType& oldModuleDelta,
-                                                      DeltaFlowDataType& newModuleDelta,
-                                                      std::vector<FlowDataType>& moduleFlowData,
+                                                      MemDeltaFlow& oldModuleDelta,
+                                                      MemDeltaFlow& newModuleDelta,
+                                                      std::vector<FlowData>& moduleFlowData,
                                                       std::vector<unsigned int>& moduleMembers)
 {
   double deltaL = Base::getDeltaCodelengthOnMovingNode(current, oldModuleDelta, newModuleDelta, moduleFlowData, moduleMembers);
@@ -341,15 +327,14 @@ double MemMapEquation::getDeltaCodelengthOnMovingNode(InfoNode& current,
   return deltaL - delta_nodeFlow_log_nodeFlow;
 }
 
-
 // ===================================================
 // Consolidation
 // ===================================================
 
 void MemMapEquation::updateCodelengthOnMovingNode(InfoNode& current,
-                                                  DeltaFlowDataType& oldModuleDelta,
-                                                  DeltaFlowDataType& newModuleDelta,
-                                                  std::vector<FlowDataType>& moduleFlowData,
+                                                  MemDeltaFlow& oldModuleDelta,
+                                                  MemDeltaFlow& newModuleDelta,
+                                                  std::vector<FlowData>& moduleFlowData,
                                                   std::vector<unsigned int>& moduleMembers)
 {
   Base::updateCodelengthOnMovingNode(current, oldModuleDelta, newModuleDelta, moduleFlowData, moduleMembers);
@@ -365,59 +350,57 @@ void MemMapEquation::updateCodelengthOnMovingNode(InfoNode& current,
   codelength -= delta_nodeFlow_log_nodeFlow;
 }
 
-
 void MemMapEquation::updatePhysicalNodes(InfoNode& current, unsigned int oldModuleIndex, unsigned int bestModuleIndex)
 {
   // For all multiple assigned nodes
-  for (unsigned int i = 0; i < current.physicalNodes.size(); ++i) {
-    PhysData& physData = current.physicalNodes[i];
+  for (const auto& physData : current.physicalNodes) {
     ModuleToMemNodes& moduleToMemNodes = m_physToModuleToMemNodes[physData.physNodeIndex];
 
     // Remove contribution to old module
-    ModuleToMemNodes::iterator overlapIt = moduleToMemNodes.find(oldModuleIndex);
+    auto overlapIt = moduleToMemNodes.find(oldModuleIndex);
     if (overlapIt == moduleToMemNodes.end())
       throw std::length_error(io::Str() << "Couldn't find old module " << oldModuleIndex << " in physical node " << physData.physNodeIndex);
-    MemNodeSet& memNodeSet = overlapIt->second;
-    memNodeSet.sumFlow -= physData.sumFlowFromM2Node;
-    if (--memNodeSet.numMemNodes == 0)
+
+    MemNodeSet& oldMemNodeSet = overlapIt->second;
+    oldMemNodeSet.sumFlow -= physData.sumFlowFromM2Node;
+    if (--oldMemNodeSet.numMemNodes == 0)
       moduleToMemNodes.erase(overlapIt);
 
     // Add contribution to new module
     overlapIt = moduleToMemNodes.find(bestModuleIndex);
-    if (overlapIt == moduleToMemNodes.end())
+    if (overlapIt == moduleToMemNodes.end()) {
       moduleToMemNodes.insert(std::make_pair(bestModuleIndex, MemNodeSet(1, physData.sumFlowFromM2Node)));
-    else {
-      MemNodeSet& memNodeSet = overlapIt->second;
-      ++memNodeSet.numMemNodes;
-      memNodeSet.sumFlow += physData.sumFlowFromM2Node;
+    } else {
+      MemNodeSet& newMemNodeSet = overlapIt->second;
+      ++newMemNodeSet.numMemNodes;
+      newMemNodeSet.sumFlow += physData.sumFlowFromM2Node;
     }
   }
 }
 
-void MemMapEquation::addMemoryContributionsAndUpdatePhysicalNodes(InfoNode& current, DeltaFlowDataType& oldModuleDelta, DeltaFlowDataType& newModuleDelta)
+void MemMapEquation::addMemoryContributionsAndUpdatePhysicalNodes(InfoNode& current, MemDeltaFlow& oldModuleDelta, MemDeltaFlow& newModuleDelta)
 {
   unsigned int oldModuleIndex = oldModuleDelta.module;
   unsigned int bestModuleIndex = newModuleDelta.module;
 
   // For all multiple assigned nodes
-  for (unsigned int i = 0; i < current.physicalNodes.size(); ++i) {
-    PhysData& physData = current.physicalNodes[i];
+  for (const auto& physData : current.physicalNodes) {
     ModuleToMemNodes& moduleToMemNodes = m_physToModuleToMemNodes[physData.physNodeIndex];
 
     // Remove contribution to old module
-    ModuleToMemNodes::iterator overlapIt = moduleToMemNodes.find(oldModuleIndex);
+    auto overlapIt = moduleToMemNodes.find(oldModuleIndex);
     if (overlapIt == moduleToMemNodes.end())
       throw std::length_error("Couldn't find old module among physical node assignments.");
-    MemNodeSet& memNodeSet = overlapIt->second;
-    double oldPhysFlow = memNodeSet.sumFlow;
-    double newPhysFlow = memNodeSet.sumFlow - physData.sumFlowFromM2Node;
+
+    MemNodeSet& oldMemNodeSet = overlapIt->second;
+    double oldPhysFlow = oldMemNodeSet.sumFlow;
+    double newPhysFlow = oldMemNodeSet.sumFlow - physData.sumFlowFromM2Node;
     oldModuleDelta.sumDeltaPlogpPhysFlow += infomath::plogp(newPhysFlow) - infomath::plogp(oldPhysFlow);
     oldModuleDelta.sumPlogpPhysFlow += infomath::plogp(physData.sumFlowFromM2Node);
-    memNodeSet.sumFlow -= physData.sumFlowFromM2Node;
-    if (--memNodeSet.numMemNodes == 0)
+    oldMemNodeSet.sumFlow -= physData.sumFlowFromM2Node;
+    if (--oldMemNodeSet.numMemNodes == 0)
       moduleToMemNodes.erase(overlapIt);
 
-
     // Add contribution to new module
     overlapIt = moduleToMemNodes.find(bestModuleIndex);
     if (overlapIt == moduleToMemNodes.end()) {
@@ -427,43 +410,40 @@ void MemMapEquation::addMemoryContributionsAndUpdatePhysicalNodes(InfoNode& curr
       newModuleDelta.sumDeltaPlogpPhysFlow += infomath::plogp(newPhysFlow) - infomath::plogp(oldPhysFlow);
       newModuleDelta.sumPlogpPhysFlow += infomath::plogp(physData.sumFlowFromM2Node);
     } else {
-      MemNodeSet& memNodeSet = overlapIt->second;
-      oldPhysFlow = memNodeSet.sumFlow;
-      newPhysFlow = memNodeSet.sumFlow + physData.sumFlowFromM2Node;
+      MemNodeSet& newMemNodeSet = overlapIt->second;
+      oldPhysFlow = newMemNodeSet.sumFlow;
+      newPhysFlow = newMemNodeSet.sumFlow + physData.sumFlowFromM2Node;
       newModuleDelta.sumDeltaPlogpPhysFlow += infomath::plogp(newPhysFlow) - infomath::plogp(oldPhysFlow);
       newModuleDelta.sumPlogpPhysFlow += infomath::plogp(physData.sumFlowFromM2Node);
-      ++memNodeSet.numMemNodes;
-      memNodeSet.sumFlow += physData.sumFlowFromM2Node;
+      ++newMemNodeSet.numMemNodes;
+      newMemNodeSet.sumFlow += physData.sumFlowFromM2Node;
     }
   }
 }
 
-
 void MemMapEquation::consolidateModules(std::vector<InfoNode*>& modules)
 {
   std::map<unsigned int, std::map<unsigned int, unsigned int>> validate;
 
   for (unsigned int i = 0; i < m_numPhysicalNodes; ++i) {
     ModuleToMemNodes& modToMemNodes = m_physToModuleToMemNodes[i];
-    for (ModuleToMemNodes::iterator overlapIt = modToMemNodes.begin(); overlapIt != modToMemNodes.end(); ++overlapIt) {
-      if (++validate[overlapIt->first][i] > 1)
+    for (const auto& modToMemNode : modToMemNodes) {
+      if (++validate[modToMemNode.first][i] > 1)
         throw std::domain_error("[InfomapGreedy::consolidateModules] Error updating physical nodes: duplication error");
 
-      modules[overlapIt->first]->physicalNodes.push_back(PhysData(i, overlapIt->second.sumFlow));
+      modules[modToMemNode.first]->physicalNodes.emplace_back(i, modToMemNode.second.sumFlow);
     }
   }
 }
 
-
 // ===================================================
 // Debug
 // ===================================================
 
-void MemMapEquation::printDebug()
+void MemMapEquation::printDebug() const
 {
   std::cout << "MemMapEquation::m_numPhysicalNodes: " << m_numPhysicalNodes << "\n";
   Base::printDebug();
 }
 
-
 } // namespace infomap
