@@ -1,39 +1,22 @@
-/**********************************************************************************
-
+/*******************************************************************************
  Infomap software package for multi-level network clustering
+ Copyright (c) 2013, 2014 Daniel Edler, Anton Eriksson, Martin Rosvall
 
- Copyright (c) 2013, 2014 Daniel Edler, Martin Rosvall
-
+ This file is part of the Infomap software package.
+ See file LICENSE_AGPLv3.txt for full license details.
  For more information, see <http://www.mapequation.org>
-
-
- This file is part of Infomap software package.
-
- Infomap software package is free software: you can redistribute it and/or modify
- it under the terms of the GNU Affero General Public License as published by
- the Free Software Foundation, either version 3 of the License, or
- (at your option) any later version.
-
- Infomap software package is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU Affero General Public License for more details.
-
- You should have received a copy of the GNU Affero General Public License
- along with Infomap software package.  If not, see <http://www.gnu.org/licenses/>.
-
-**********************************************************************************/
-
+ ******************************************************************************/
 
 #include "StateNetwork.h"
 #include "../utils/FlowCalculator.h"
 #include "../utils/Log.h"
-#include "../utils/exceptions.h"
 #include "../io/SafeFile.h"
+#include <stdexcept>
+#include <utility>
 
 namespace infomap {
 
-std::pair<StateNetwork::NodeMap::iterator, bool> StateNetwork::addStateNode(StateNode node)
+std::pair<StateNetwork::NodeMap::iterator, bool> StateNetwork::addStateNode(const StateNode& node)
 {
   auto ret = m_nodes.insert(StateNetwork::NodeMap::value_type(node.id, node));
   if (ret.second) {
@@ -67,13 +50,13 @@ std::pair<StateNetwork::NodeMap::iterator, bool> StateNetwork::addNode(unsigned
 
 std::pair<StateNetwork::NodeMap::iterator, bool> StateNetwork::addNode(unsigned int id, std::string name)
 {
-  m_names[id] = name;
+  m_names[id] = std::move(name);
   return addNode(id);
 }
 
 std::pair<StateNetwork::NodeMap::iterator, bool> StateNetwork::addNode(unsigned int id, std::string name, double weight)
 {
-  m_names[id] = name;
+  m_names[id] = std::move(name);
   return addNode(id, weight);
 }
 
@@ -96,7 +79,6 @@ StateNetwork::PhysNode& StateNetwork::addPhysicalNode(unsigned int physId, doubl
 StateNetwork::PhysNode& StateNetwork::addPhysicalNode(unsigned int physId, const std::string& name)
 {
   auto& physNode = addPhysicalNode(physId);
-  // physNode.name = name;
   m_names[physId] = name;
   m_sumNodeWeight += 1.0;
   return physNode;
@@ -106,16 +88,13 @@ StateNetwork::PhysNode& StateNetwork::addPhysicalNode(unsigned int physId, doubl
 {
   auto& physNode = addPhysicalNode(physId);
   physNode.weight = weight;
-  // physNode.name = name;
   m_sumNodeWeight += weight;
   m_names[physId] = name;
   return physNode;
 }
 
-
-std::pair<std::map<unsigned int, std::string>::iterator, bool> StateNetwork::addName(unsigned int id, std::string name)
+std::pair<std::map<unsigned int, std::string>::iterator, bool> StateNetwork::addName(unsigned int id, const std::string& name)
 {
-  // m_names[id] = name;
   return m_names.insert(std::make_pair(id, name));
 }
 
@@ -136,88 +115,33 @@ bool StateNetwork::addLink(unsigned int sourceId, unsigned int targetId, double
     ++m_numSelfLinks;
     m_sumSelfLinkWeight += weight;
   }
-  // const auto& sourceNode = m_nodes.emplace(sourceId, StateNode(sourceId)).first;
-  // const auto& targetNode = m_nodes.emplace(targetId, StateNode(targetId)).first;
-  // m_nodes.emplace(sourceId, StateNode(sourceId));
-  // m_nodes.emplace(targetId, StateNode(targetId));
+
   addNode(sourceId);
   addNode(targetId);
 
-
   ++m_numLinks;
   m_sumLinkWeight += weight;
 
   bool addedNewLink = true;
 
-  // Log() << "Add link " << sourceId << " -> " << targetId << ", weight: " << weight << "\n";
   // Aggregate link weights if they are defined more than once
   auto& outLinks = m_nodeLinkMap[sourceId];
   if (outLinks.empty()) {
     outLinks[targetId] = weight;
-    // Log() << "  -> new source link!\n";
   } else {
-    // auto& ret = outLinks.emplace(targetNode, weight);
-    // if (!ret.second)
-    // auto& linkData = ret.first;
-    // Log() << " " << outLinks.size() << " outlinks exist: ";
-    // for (auto& it : outLinks) {
-    // 	Log() << "\n  " << it.first.id << ": weight: " << it.second.weight << ", count: " << it.second.count << ".. ";
-    // }
-    // auto& linkData = outLinks[targetId];
     auto ret = outLinks.insert(std::make_pair(StateNode(targetId), LinkData(weight)));
-    // ++linkData.count;
-    // Log() << "\n ++count -> weight: " << linkData.weight << ", count: " << linkData.count << ".. ";
     auto& linkData = ret.first->second;
-    // if (linkData.count != 1) {
     if (!ret.second) {
-      // Log() << "  -> existing weight: " << linkData.weight;
       linkData.weight += weight;
-      // Log() << " -> weight: " << linkData.weight << "\n";
-      // Log() << "    -> count: " << linkData.count << ", weight: " << linkData.weight << "\n";
       ++m_numAggregatedLinks;
       --m_numLinks;
       addedNewLink = false;
     } else {
-      // Log() << "  -> new target link!\n";
       linkData.weight = weight;
     }
   }
   m_outWeights[sourceId] += weight;
-  // printNetwork();
   return addedNewLink;
-  // auto& ret = m_nodeLinkMap.emplace(sourceId, std::make_pair(StateNode(), LinkData()));
-  // if (!ret.second) {
-  // 	ret.first[targetId] = weight;
-  // }
-  // else {
-  // 	auto& ret2 = ret.first.emplace(targetId, weight);
-  // 	if (!ret2.second) {
-  // 		ret2.first += weight;
-  // 		++m_numAggregatedLinks;
-  // 		--m_numLinks;
-  // 		return false;
-  // 	}
-  // }
-  // return true;
-
-  // LinkMap::iterator firstIt = m_links.lower_bound(sourceId);
-  // if (firstIt != m_links.end() && firstIt->first == sourceId) // First linkEnd already exists, check second linkEnd
-  // {
-  // 	std::pair<std::map<unsigned int, double>::iterator, bool> ret2 = firstIt->second.insert(std::make_pair(targetId, weight));
-  // 	if (!ret2.second)
-  // 	{
-  // 		ret2.first->second += weight;
-  // 		++m_numAggregatedLinks;
-  // 		--m_numLinks;
-  // 		return false;
-  // 	}
-  // }
-  // else
-  // {
-  // 	m_links.insert(firstIt, std::make_pair(sourceId, std::map<unsigned int, double>()))->second.insert(std::make_pair(targetId, weight));
-  // }
-
-  // return true;
 }
 
 bool StateNetwork::addLink(unsigned int sourceId, unsigned int targetId, unsigned long weight)
@@ -248,7 +172,6 @@ bool StateNetwork::removeLink(unsigned int sourceId, unsigned int targetId)
     --m_numAggregatedLinks;
   }
 
-
   --m_numLinks;
   m_sumLinkWeight -= weight;
   m_totalLinkWeightAdded -= weight;
@@ -280,7 +203,7 @@ bool StateNetwork::undirectedToDirected()
         continue; // Self-links are treated as directed on undirected networks
       }
       double weight = subIt.second.weight;
-      oppositeLinks.push_back(StateLink(targetId, sourceId, weight));
+      oppositeLinks.emplace_back(targetId, sourceId, weight);
     }
   }
   for (auto& link : oppositeLinks) {
@@ -296,11 +219,7 @@ void StateNetwork::calculateFlow()
 
 void StateNetwork::clearLinks()
 {
-  // m_nodes.clear();
   m_nodeLinkMap.clear();
-  // m_physNodes.clear();
-  // m_outWeights.clear();
-  // m_names.clear();
 }
 
 void StateNetwork::clear()
@@ -313,9 +232,7 @@ void StateNetwork::clear()
 
   m_haveDirectedInput = false;
   m_haveMemoryInput = false;
-  m_numNodesFound = 0;
   m_numStateNodesFound = 0;
-  m_numLinksFound = 0;
   m_numLinks = 0;
   m_numSelfLinksFound = 0;
   m_sumLinkWeight = 0.0;
@@ -327,10 +244,10 @@ void StateNetwork::clear()
   m_totalLinkWeightIgnored = 0.0;
 }
 
-void StateNetwork::writeStateNetwork(std::string filename) const
+void StateNetwork::writeStateNetwork(const std::string& filename) const
 {
   if (filename.empty())
-    throw BadArgumentError("writeStateNetwork called with empty filename");
+    throw std::runtime_error("writeStateNetwork called with empty filename");
 
   SafeOutFile outFile(filename);
 
@@ -365,10 +282,10 @@ void StateNetwork::writeStateNetwork(std::string filename) const
   }
 }
 
-void StateNetwork::writePajekNetwork(std::string filename, bool printFlow) const
+void StateNetwork::writePajekNetwork(const std::string& filename, bool printFlow) const
 {
   if (filename.empty())
-    throw BadArgumentError("writePajekNetwork called with empty filename");
+    throw std::runtime_error("writePajekNetwork called with empty filename");
 
   SafeOutFile outFile(filename);
 
@@ -408,7 +325,8 @@ std::pair<StateNetwork::NodeMap::iterator, bool> StateNetwork::addStateNodeWithA
   return addStateNode(stateId, physId);
 }
 
-std::pair<StateNetwork::NodeMap::iterator, bool> StateNetwork::addStateNodeWithDeterministicId(unsigned int physId, unsigned int layerId, unsigned int numLayersLog2) {
+std::pair<StateNetwork::NodeMap::iterator, bool> StateNetwork::addStateNodeWithDeterministicId(unsigned int physId, unsigned int layerId, unsigned int numLayersLog2)
+{
   unsigned int stateId = physId << (numLayersLog2 + 1) | layerId;
   return addStateNode(stateId, physId);
 }
