@@ -1,37 +1,19 @@
-/**********************************************************************************
-
+/*******************************************************************************
  Infomap software package for multi-level network clustering
+ Copyright (c) 2013, 2014 Daniel Edler, Anton Eriksson, Martin Rosvall
 
- Copyright (c) 2013, 2014 Daniel Edler, Martin Rosvall
-
+ This file is part of the Infomap software package.
+ See file LICENSE_AGPLv3.txt for full license details.
  For more information, see <http://www.mapequation.org>
-
-
- This file is part of Infomap software package.
-
- Infomap software package is free software: you can redistribute it and/or modify
- it under the terms of the GNU Affero General Public License as published by
- the Free Software Foundation, either version 3 of the License, or
- (at your option) any later version.
-
- Infomap software package is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU Affero General Public License for more details.
-
- You should have received a copy of the GNU Affero General Public License
- along with Infomap software package.  If not, see <http://www.gnu.org/licenses/>.
-
-**********************************************************************************/
-
+ ******************************************************************************/
 
 #include "ProgramInterface.h"
+#include "../utils/Log.h"
+
 #include <iostream>
 #include <cstdlib>
 #include <map>
 #include <utility>
-#include "convert.h"
-#include "../utils/Log.h"
 
 namespace infomap {
 
@@ -63,36 +45,28 @@ ProgramInterface::ProgramInterface(std::string name, std::string shortDescriptio
   addOptionArgument(m_printJsonParameters, "print-json-parameters", "Print Infomap parameters in JSON.", "About").setHidden(true);
 }
 
-ProgramInterface::~ProgramInterface()
-{
-  for (auto& arg : m_nonOptionArguments)
-    delete arg;
-  for (auto& arg : m_optionArguments)
-    delete arg;
-}
-
 void ProgramInterface::exitWithUsage(bool showAdvanced)
 {
-  Log() << "Name:" << std::endl;
-  Log() << "        " << m_programName << " - " << m_shortProgramDescription << std::endl;
-  Log() << "\nUsage:" << std::endl;
+  Log() << "Name:\n";
+  Log() << "        " << m_programName << " - " << m_shortProgramDescription << '\n';
+  Log() << "\nUsage:\n";
   Log() << "        " << m_executableName;
   for (auto& nonOptionArgument : m_nonOptionArguments)
     if (showAdvanced || !nonOptionArgument->isAdvanced)
       Log() << " " << nonOptionArgument->variableName;
   if (!m_optionArguments.empty())
     Log() << " [options]";
-  Log() << std::endl;
+  Log() << '\n';
 
   if (!m_programDescription.empty())
-    Log() << "\nDescription:\n        " << m_programDescription << std::endl;
+    Log() << "\nDescription:\n        " << m_programDescription << '\n';
 
   for (auto& nonOptionArgument : m_nonOptionArguments)
     if (showAdvanced || !nonOptionArgument->isAdvanced)
-      Log() << "\n[" << nonOptionArgument->variableName << "]\n    " << nonOptionArgument->description << std::endl;
+      Log() << "\n[" << nonOptionArgument->variableName << "]\n    " << nonOptionArgument->description << '\n';
 
   if (!m_optionArguments.empty())
-    Log() << "\n[options]" << std::endl;
+    Log() << "\n[options]\n";
 
   // First stringify the options part to get the maximum length
   std::deque<std::string> optionStrings(m_optionArguments.size());
@@ -100,8 +74,10 @@ void ProgramInterface::exitWithUsage(bool showAdvanced)
   for (unsigned int i = 0; i < m_optionArguments.size(); ++i) {
     auto& opt = *m_optionArguments[i];
     bool haveShort = opt.shortName != '\0';
-    std::string optArgShort = opt.requireArgument ? (io::Str() << "<" << ArgType::toShort.at(opt.argumentName) << ">") : opt.incrementalArgument ? "[+]" : std::string(3, ' ');
-    std::string optArgLong = opt.requireArgument ? (io::Str() << "<" << opt.argumentName << ">") : opt.incrementalArgument ? "[+]" : std::string(3, ' ');
+    std::string optArgShort = opt.requireArgument ? (io::Str() << "<" << ArgType::toShort.at(opt.argumentName) << ">") : opt.incrementalArgument ? "[+]"
+                                                                                                                                                 : std::string(3, ' ');
+    std::string optArgLong = opt.requireArgument ? (io::Str() << "<" << opt.argumentName << ">") : opt.incrementalArgument ? "[+]"
+                                                                                                                           : std::string(3, ' ');
     std::string shortOption = haveShort ? (io::Str() << "  -" << opt.shortName << optArgShort) : std::string(7, ' ');
     optionStrings[i] = io::Str() << shortOption << " --" << opt.longName << " " << optArgLong;
     if (optionStrings[i].length() > maxLength)
@@ -135,7 +111,7 @@ void ProgramInterface::exitWithUsage(bool showAdvanced)
       }
     }
   }
-  Log() << std::endl;
+  Log() << '\n';
   std::exit(0);
 }
 
@@ -145,12 +121,12 @@ void ProgramInterface::exitWithVersionInformation()
 #ifdef _OPENMP
   Log() << " compiled with OpenMP";
 #endif
-  Log() << std::endl;
-  Log() << "See www.mapequation.org for terms of use." << std::endl;
+  Log() << '\n';
+  Log() << "See www.mapequation.org for terms of use.\n";
   std::exit(0);
 }
 
-void ProgramInterface::exitWithError(std::string message)
+void ProgramInterface::exitWithError(const std::string& message)
 {
   Log() << m_programName << " version " << m_programVersion;
 #ifdef _OPENMP
@@ -164,7 +140,7 @@ void ProgramInterface::exitWithError(std::string message)
       Log() << " " << nonOptionArgument->variableName;
   if (!m_optionArguments.empty())
     Log() << " [options]";
-  Log() << ". Run with option '-h' for more information." << std::endl;
+  Log() << ". Run with option '-h' for more information.\n";
   std::exit(1);
 }
 
@@ -231,7 +207,6 @@ std::string ProgramInterface::toJson(const Option& opt)
                    << " }";
 }
 
-
 void ProgramInterface::parseArgs(const std::string& args)
 {
   // Map the options on short and long name, and check for duplication
@@ -242,45 +217,46 @@ void ProgramInterface::parseArgs(const std::string& args)
     if (opt.shortName != '\0') {
       auto it = shortOptionMap.find(opt.shortName);
       if (it != shortOptionMap.end())
-        throw OptionConflictError(io::Str() << "Duplication of option '" << opt.shortName << "'");
+        throw std::runtime_error(io::Str() << "Duplication of option '" << opt.shortName << "'");
       shortOptionMap.insert(std::make_pair(opt.shortName, &opt));
     }
 
     auto it = longOptionMap.find(opt.longName);
     if (it != longOptionMap.end())
-      throw OptionConflictError(io::Str() << "Duplication of option \"" << opt.longName << "\"");
+      throw std::runtime_error(io::Str() << "Duplication of option \"" << opt.longName << "\"");
     longOptionMap.insert(std::make_pair(opt.longName, &opt));
   }
 
   // Split the flags on whitespace
   std::vector<std::string> flags;
   std::istringstream argStream(args);
-  std::string arg;
-  while (!(argStream >> arg).fail())
-    flags.push_back(arg);
+
+  {
+    std::string arg;
+    while (!(argStream >> arg).fail())
+      flags.push_back(arg);
+  }
 
   std::deque<std::string> nonOpts;
   try {
     for (unsigned int i = 0; i < flags.size(); ++i) {
-      //bool negate = m_negateNextOption;
-      m_negateNextOption = false;
       bool flagValue = true;
       unsigned int numArgsLeft = flags.size() - i - 1;
 
       const std::string& arg = flags[i];
       if (arg.length() == 0)
-        throw InputSyntaxError("Illegal argument ''");
+        throw std::runtime_error("Illegal argument ''");
 
       if (arg[0] != '-') {
         nonOpts.push_back(arg);
       } else {
         if (arg.length() < 2)
-          throw InputSyntaxError("Illegal argument '-'");
+          throw std::runtime_error("Illegal argument '-'");
 
         if (arg[1] == '-') {
           // Long option
           if (arg.length() < 3)
-            throw InputSyntaxError("Illegal argument '--'");
+            throw std::runtime_error("Illegal argument '--'");
           std::string longOpt = arg.substr(2);
           auto it = longOptionMap.find(longOpt);
           if (it == longOptionMap.end()) {
@@ -290,7 +266,7 @@ void ProgramInterface::parseArgs(const std::string& args)
               it = longOptionMap.find(longOpt);
               flagValue = false;
             } else {
-              throw InputDomainError(io::Str() << "Unrecognized option: '--" << longOpt << "'");
+              throw std::runtime_error(io::Str() << "Unrecognized option: '--" << longOpt << "'");
             }
           }
           auto& opt = *it->second;
@@ -298,21 +274,19 @@ void ProgramInterface::parseArgs(const std::string& args)
             opt.set(flagValue);
           else {
             if (numArgsLeft == 0)
-              throw InputDomainError(io::Str() << "Option '" << opt.longName << "' requires argument");
+              throw std::runtime_error(io::Str() << "Option '" << opt.longName << "' requires argument");
             ++i;
             if (!opt.parse(flags[i]))
-              throw InputDomainError(io::Str() << "Cannot parse '" << flags[i] << "' as argument to option '" << opt.longName << "'. ");
+              throw std::runtime_error(io::Str() << "Cannot parse '" << flags[i] << "' as argument to option '" << opt.longName << "'. ");
           }
         } else {
           // Short option(s)
           for (unsigned int j = 1; j < arg.length(); ++j) {
-            //negate = m_negateNextOption;
-            m_negateNextOption = false;
             char o = arg[j];
             unsigned int numCharsLeft = arg.length() - j - 1;
             auto it = shortOptionMap.find(o);
             if (it == shortOptionMap.end())
-              throw InputDomainError(io::Str() << "Unrecognized option: '-" << o << "'");
+              throw std::runtime_error(io::Str() << "Unrecognized option: '-" << o << "'");
             auto& opt = *it->second;
             if (!opt.requireArgument || opt.incrementalArgument)
               opt.set(flagValue);
@@ -325,10 +299,10 @@ void ProgramInterface::parseArgs(const std::string& args)
                 ++i;
                 optArg = flags[i];
               } else
-                throw InputDomainError(io::Str() << "Option '" << opt.longName << "' requires argument");
+                throw std::runtime_error(io::Str() << "Option '" << opt.longName << "' requires argument");
 
               if (!opt.parse(optArg))
-                throw InputDomainError(io::Str() << "Cannot parse '" << optArg << "' as argument to option '" << opt.longName << "'. ");
+                throw std::runtime_error(io::Str() << "Cannot parse '" << optArg << "' as argument to option '" << opt.longName << "'. ");
             }
           }
         }
