@@ -1,29 +1,11 @@
-/**********************************************************************************
-
+/*******************************************************************************
  Infomap software package for multi-level network clustering
+ Copyright (c) 2013, 2014 Daniel Edler, Anton Eriksson, Martin Rosvall
 
- Copyright (c) 2013, 2014 Daniel Edler, Martin Rosvall
-
+ This file is part of the Infomap software package.
+ See file LICENSE_AGPLv3.txt for full license details.
  For more information, see <http://www.mapequation.org>
-
-
- This file is part of Infomap software package.
-
- Infomap software package is free software: you can redistribute it and/or modify
- it under the terms of the GNU Affero General Public License as published by
- the Free Software Foundation, either version 3 of the License, or
- (at your option) any later version.
-
- Infomap software package is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU Affero General Public License for more details.
-
- You should have received a copy of the GNU Affero General Public License
- along with Infomap software package.  If not, see <http://www.gnu.org/licenses/>.
-
-**********************************************************************************/
-
+ ******************************************************************************/
 
 #include "FlowCalculator.h"
 #include "../utils/Log.h"
@@ -34,6 +16,7 @@
 #include <limits>
 #include <algorithm>
 #include <functional>
+
 namespace infomap {
 
 template <typename T>
@@ -61,7 +44,6 @@ FlowCalculator::FlowCalculator(StateNetwork& network, const Config& config)
 
   nodeFlow.assign(numNodes, 0.0);
   nodeTeleportWeights.assign(numNodes, 0.0); // Fraction of teleportation flow landing on node i
-  // nodeTeleportFlow.assign(numNodes, 0.0); // Outgoing teleportation flow from node i
 
   nodeOutDegree.assign(numNodes, 0);
   sumLinkOutWeight.assign(numNodes, 0.0);
@@ -282,7 +264,7 @@ IterationResult powerIterate(double alpha, Iteration&& iter)
     ++iterations;
   } while (iterations < 200 && (err > 1.0e-15 || iterations < 50));
 
-  Log() << "\n  -> PageRank calculation done in " << iterations << " iterations." << std::endl;
+  Log() << "\n  -> PageRank calculation done in " << iterations << " iterations.\n";
 
   return { alpha, beta };
 }
@@ -323,7 +305,7 @@ void FlowCalculator::calcDirectedFlow(const StateNetwork& network, const Config&
   double danglingRank;
 
   // Calculate PageRank
-  const auto iteration = [&](const auto iteration, const double alpha, const double beta) {
+  const auto iteration = [&](const auto iter, const double alpha, const double beta) {
     danglingRank = std::accumulate(cbegin(nodeFlow), cbegin(nodeFlow) + nonDanglingStartIndex, 0.0);
 
     // Flow from teleportation
@@ -349,7 +331,7 @@ void FlowCalculator::calcDirectedFlow(const StateNetwork& network, const Config&
 
     // Normalize if needed
     if (std::abs(nodeFlowDiff) > 1.0e-10) {
-      Log() << "(Normalizing ranks after " << iteration << " power iterations with error " << nodeFlowDiff << ") ";
+      Log() << "(Normalizing ranks after " << iter << " power iterations with error " << nodeFlowDiff << ") ";
       normalize(nodeFlow, nodeFlowDiff + 1.0);
     }
 
@@ -403,55 +385,38 @@ void FlowCalculator::calcDirectedRegularizedFlow(const StateNetwork& network, co
     s_in[link.target] += link.flow;
   }
 
-  double min_u_out = 	std::numeric_limits<double>::max();
-  double min_u_in = 	std::numeric_limits<double>::max();
+  double min_u_out = std::numeric_limits<double>::max();
+  double min_u_in = std::numeric_limits<double>::max();
   for (unsigned int i = 0; i < N; ++i) {
     if (k_out[i] > 0) {
-      min_u_out =  std::min(min_u_out, s_out[i] / k_out[i]);
+      min_u_out = std::min(min_u_out, s_out[i] / k_out[i]);
     }
     if (k_in[i] > 0) {
       min_u_in = std::min(min_u_in, s_in[i] / k_in[i]);
     }
   }
 
-  auto s = [s_in, s_out](auto i) { return s_in[i] + s_out[i]; };
-  auto k = [k_in, k_out](auto i) { return k_in[i] + k_out[i]; };
   auto u_out = [s_out, k_out, min_u_out](auto i) { return k_out[i] == 0 ? min_u_out : s_out[i] / k_out[i]; };
   auto u_in = [s_in, k_in, min_u_in](auto i) { return k_in[i] == 0 ? min_u_in : s_in[i] / k_in[i]; };
-  auto u_ij = [u_in, u_out](auto i, auto j) { return u_out(i) * u_in(j); };
 
   unsigned int numNodesAsTeleportationTargets = config.noSelfLinks ? N - 1 : N;
   double lambda = config.regularizationStrength * std::log(N) / numNodesAsTeleportationTargets;
   double u_t = average_weight;
-  // for (unsigned int i = 0; i < N; ++i) {
-  //   u_t += k(i) == 0 ? 0 : s(i) / k(i);
-  // }
+
   double sum_u_in = 0.0;
-  double sum_s_in = 0.0;
   for (unsigned int i = 0; i < N; ++i) {
     sum_u_in += u_in(i);
-    sum_s_in += s_in[i];
   }
 
-  // nodeTeleportWeights is the fraction of teleportation flow landing on each node. This is proportional to u_in
-  // Log() << "\n\n Node tele weights:\n";
   for (unsigned int i = 0; i < N; ++i) {
     nodeTeleportWeights[i] = u_in(i) / sum_u_in;
-    // nodeTeleportWeights[i] = s_in[i] / sum_s_in;
-    // Log() << "  " << i << ": " << nodeTeleportWeights[i] << " (u_in: " << u_in(i) <<
-    // ", k_in: " << k_in[i] << ", s_in: " << s_in[i] << ")\n";
   }
 
-  auto t_ij = [lambda, u_t, u_ij](auto i, auto j) { return lambda / u_t * u_ij(i, j); };
-  // auto t_out_withoutSelfLinks = [lambda, u_t, u_out, u_in, sum_u_in](unsigned int i) { return lambda/u_t * u_out(i) * (sum_u_in - u_in(i)); };
-  // auto t_out_withSelfLinks = [lambda, u_t, u_out, sum_u_in](unsigned int i) { return lambda/u_t * u_out(i) * sum_u_in; };
   std::function<double(unsigned int)> t_out_withoutSelfLinks = [lambda, u_t, u_out, u_in, sum_u_in](unsigned int i) { return lambda / u_t * u_out(i) * (sum_u_in - u_in(i)); };
   std::function<double(unsigned int)> t_out_withSelfLinks = [lambda, u_t, u_out, sum_u_in](unsigned int i) { return lambda / u_t * u_out(i) * sum_u_in; };
   auto t_out = config.noSelfLinks ? t_out_withoutSelfLinks : t_out_withSelfLinks;
 
   std::vector<double> alpha(N, 0);
-  // Log() << "\nt_i (lambda: " << lambda << ", u_t: " << u_t << ", sum_u_in: " << sum_u_in << "): ";
-  double sumAlpha = 0.0;
   for (unsigned int i = 0; i < N; ++i) {
     auto t_i = t_out(i);
     alpha[i] = t_i / (s_out[i] + t_i); // = 1 for dangling nodes
@@ -460,16 +425,7 @@ void FlowCalculator::calcDirectedRegularizedFlow(const StateNetwork& network, co
       // TODO: Check possible side-effects
       alpha[i] /= 1 - nodeTeleportWeights[i];
     }
-    sumAlpha += alpha[i];
   }
-  // Log() << "\n";
-
-  // for (unsigned int i = 0; i < N; ++i) {
-  //   Log() << i << ": k_out: " << k_out[i] << ", k_in: " << k_in[i] << ", " <<
-  //   "s_out: " << s_out[i] << ", s_in: " << s_in[i] << ", t_out: " << t_out(i) << ", alpha: " << alpha[i] << "\n";
-  // }
-
-  // Log() << "\n";
 
   // Normalize link weights with respect to its source nodes total out-link weight;
   for (auto& link : flowLinks) {
@@ -481,46 +437,20 @@ void FlowCalculator::calcDirectedRegularizedFlow(const StateNetwork& network, co
   std::vector<double> nodeFlowTmp(numNodes, 0.0);
 
   // Calculate PageRank
-  const auto iteration = [&](const auto iteration) {
-    // Flow from teleportation, remove self-teleportation
-    // double teleportationFlow = 0.0;
+  const auto iteration = [&](const auto iter) {
     double teleTmp = 0.0;
     for (unsigned int i = 0; i < N; ++i) {
-      // teleportationFlow += alpha[i] * nodeFlow[i];
-      // teleTmp += alpha[i] * nodeFlow[i] / (sum_u_in - u_in(i));
       teleTmp += alpha[i] * nodeFlow[i];
     }
-    // double tmp1 = 0;
-    for (unsigned int i = 0; i < N; ++i) {
-      // nodeFlowTmp[i] = u_in(i) / sum_u_in * (teleportationFlow - alpha[i] * nodeFlow[i]);
-      // nodeFlowTmp[i] = u_in(i) * (teleTmp - alpha[i] * nodeFlow[i] / (sum_u_in - u_in(i)));
-      // nodeFlowTmp[i] = nodeTeleportWeights[i] * (teleTmp - alpha[i] * nodeFlow[i]);
-      nodeFlowTmp[i] = nodeTeleportWeights[i] * (config.noSelfLinks ? (teleTmp - alpha[i] * nodeFlow[i]) : teleTmp);
-      // nodeFlowTmp[i] = nodeTeleportWeights[i] * teleTmp;
-      // tmp1 += nodeFlowTmp[i];
-      // if (i == 0 && iteration < 2) {
-      //   Log() << "\nNode 0: u_in: " << u_in(i) << ", teleTmp: " << teleTmp << ", alpha: " << alpha[i] <<
-      //   ", nodeFlow: " << nodeFlow[i] << ", sum_u_in: " << sum_u_in << "\n";
-      // }
-    }
-    // if (iteration < 2 || iteration == 49) {
-    //   Log() << "Iter " << iteration << ": Sum tele tmp: " << tmp1 << ", teleTmp: " << teleTmp << ", sumAlpha: " << sumAlpha << "\n";
-    // }
-    // double tmp2 = 0.0;
-    // for (unsigned int i = 0; i < N; ++i) {
-    //   nodeFlowTmp[i] /= tmp1/teleTmp;
-    //   tmp2 += nodeFlowTmp[i];
-    // }
-    // if (iteration < 2) {
-    //   Log() << "=> Sum 2: " << tmp2 << "\n";
-    // }
 
+    for (unsigned int i = 0; i < N; ++i) {
+      nodeFlowTmp[i] = nodeTeleportWeights[i] * (config.noSelfLinks ? (teleTmp - alpha[i] * nodeFlow[i]) : teleTmp);
+    }
 
     // Flow from links
     for (const auto& link : flowLinks) {
       double beta = 1 - alpha[link.source] * (config.noSelfLinks ? 1 - nodeTeleportWeights[link.source] : 1);
       nodeFlowTmp[link.target] += beta * link.flow * nodeFlow[link.source];
-      // nodeFlowTmp[link.target] += (1 - alpha[link.source]) * link.flow * nodeFlow[link.source];
     }
 
     // Update node flow from the power iteration above and check if converged
@@ -530,22 +460,18 @@ void FlowCalculator::calcDirectedRegularizedFlow(const StateNetwork& network, co
       nodeFlowDiff += nodeFlowTmp[i];
       error += std::abs(nodeFlowTmp[i] - nodeFlow[i]);
     }
-    // Log() << iteration << ": teleportFlow: " << teleportationFlow << ", tele nodeFlow: " << tmp1 <<
-    // ", nodeFlowDiff: " << nodeFlowDiff << ", error: " << error << "\n";
 
     nodeFlow = nodeFlowTmp;
 
     // Normalize if needed
     if (std::abs(nodeFlowDiff) > 1.0e-10) {
-      Log() << "(Normalizing ranks after " << iteration << " power iterations with error " << nodeFlowDiff << ") ";
+      Log() << "(Normalizing ranks after " << iter << " power iterations with error " << nodeFlowDiff << ") ";
       normalize(nodeFlow, nodeFlowDiff + 1.0);
     }
 
     return error;
   };
 
-  // Log() << "\nDo power iteration!\n";
-  // const auto result = powerIterate2(iteration);
   unsigned int iterations = 0;
   double err = 0.0;
 
@@ -558,42 +484,20 @@ void FlowCalculator::calcDirectedRegularizedFlow(const StateNetwork& network, co
     }
 
     ++iterations;
-    // if (iterations == 10) {
-    //   break;
-    // }
   } while (iterations < 200 && (err > 1.0e-15 || iterations < 50));
 
-  Log() << "\n  -> PageRank calculation done in " << iterations << " iterations." << std::endl;
+  Log() << "\n  -> PageRank calculation done in " << iterations << " iterations.\n";
 
   double sumNodeRank = 1.0;
-  // double tmpN = 0.0;
-  // for (auto& flow : nodeFlow) {
-  //   tmpN += flow;
-  // }
-  // double tmpE = 0;
-  // Update the links with their global flow from the PageRank values.
   for (auto& link : flowLinks) {
     double beta = 1 - alpha[link.source] * (config.noSelfLinks ? 1 - nodeTeleportWeights[link.source] : 1);
     link.flow *= beta * nodeFlow[link.source] / sumNodeRank;
-    // tmpE += link.flow;
   }
 
-  // enterFlow = nodeFlow;
-  // exitFlow = nodeFlow;
   nodeTeleportFlow.assign(numNodes, 0.0);
   for (unsigned int i = 0; i < N; ++i) {
     nodeTeleportFlow[i] = nodeFlow[i] * alpha[i];
   }
-
-
-  // Log() << "\nSum node flow: " << tmpN << ", sum link flow: " << tmpE << "\n\n";
-  // Log() << "Node flow (sum: " << tmpN << "):\n";
-  // for (unsigned int i = 0; i < N; ++i)
-  //   Log() << i << ": flow:  " << nodeFlow[i] << ", teleWeight: " << nodeTeleportWeights[i] << ", alpha: " << alpha[i] << ", adj alpha: " << alpha[i] * (1 - nodeTeleportWeights[i]) << ", t_out: " << t_out(i) << ", s_out: " << s_out[i] << ", k_out: " << k_out[i] << "\n";
-  // Log() << "Link flow (sum: " << tmpE << "):\n";
-  // // for (auto& link : flowLinks)
-  // //   Log() << "  " << link.flow << ", ";
-  // Log() << "\n";
 }
 
 void FlowCalculator::calcUndirectedRegularizedFlow(const StateNetwork& network, const Config& config) noexcept
@@ -617,8 +521,7 @@ void FlowCalculator::calcUndirectedRegularizedFlow(const StateNetwork& network,
     }
   }
 
-
-  double min_u = 	std::numeric_limits<double>::max();
+  double min_u = std::numeric_limits<double>::max();
   for (unsigned int i = 0; i < N; ++i) {
     if (k[i] > 0) {
       min_u = std::min(min_u, s[i] / k[i]);
@@ -626,61 +529,37 @@ void FlowCalculator::calcUndirectedRegularizedFlow(const StateNetwork& network,
   }
 
   auto u = [s, k, min_u](auto i) { return k[i] == 0 ? min_u : s[i] / k[i]; };
-  auto u_ij = [u](auto i, auto j) { return u(i) * u(j); };
 
   unsigned int numNodesAsTeleportationTargets = config.noSelfLinks ? N - 1 : N;
   double lambda = config.regularizationStrength * std::log(N) / numNodesAsTeleportationTargets;
   double u_t = average_weight;
 
-  // Log() << "\nLambda: " << lambda << ", avg weight: " << u_t << ", norm: " << lambda * u_t << "\n";
-
-  // for (unsigned int i = 0; i < N; ++i) {
-  //   u_t += k(i) == 0 ? 0 : s(i) / k(i);
-  // }
   double sum_u = 0.0;
   for (unsigned int i = 0; i < N; ++i) {
     sum_u += u(i);
   }
 
   // nodeTeleportWeights is the fraction of teleportation flow landing on each node. This is proportional to u_in
-  // Log() << "\n\n Node tele weights:\n";
   for (unsigned int i = 0; i < N; ++i) {
     nodeTeleportWeights[i] = u(i) / sum_u;
-    // Log() << "  " << i << ": " << nodeTeleportWeights[i] << " (u: " << u(i) << ", k: " << k[i] << ", s: " << s[i] << ")\n";
   }
 
-  auto t_ij = [lambda, u_t, u_ij](auto i, auto j) { return lambda / u_t * u_ij(i, j); };
-  // auto t_out_withoutSelfLinks = [lambda, u_t, u_out, u_in, sum_u](unsigned int i) { return lambda/u_t * u_out(i) * (sum_u - u_in(i)); };
-  // auto t_out_withSelfLinks = [lambda, u_t, u_out, sum_u](unsigned int i) { return lambda/u_t * u_out(i) * sum_u; };
   std::function<double(unsigned int)> t_withoutSelfLinks = [lambda, u_t, u, sum_u](unsigned int i) { return lambda / u_t * u(i) * (sum_u - u(i)); };
   std::function<double(unsigned int)> t_withSelfLinks = [lambda, u_t, u, sum_u](unsigned int i) { return lambda / u_t * u(i) * sum_u; };
   auto t = config.noSelfLinks ? t_withoutSelfLinks : t_withSelfLinks;
 
   std::vector<double> alpha(N, 0);
-  // Log() << "\nt_i (lambda: " << lambda << ", u_t: " << u_t << ", sum_u: " << sum_u << "): ";
-  double sumAlpha = 0.0;
   double sum_t = 0.0;
-  double sum_ts = 0.0;
-  double sum_t_to_ts = 0.0;
   for (unsigned int i = 0; i < N; ++i) {
     auto t_i = t(i);
     alpha[i] = t_i / (s[i] + t_i);
-    sum_t_to_ts += alpha[i];
     if (config.noSelfLinks) {
       // Inflate to adjust for no self-teleportation
       // TODO: No later side effects of cheating here? Need to normalize targets instead?
       alpha[i] /= 1 - nodeTeleportWeights[i];
     }
-    sumAlpha += alpha[i];
     sum_t += t_i;
-    sum_ts += t_i + s[i];
   }
-  // Log() << "\n";
-
-  // Log() << "Sum alpha: " << sumAlpha << ", sum t/(t+s): " << sum_t_to_ts << ", sum t: " << sum_t << ", sum t+s: " << sum_ts << ":\n";
-  // for (unsigned int i = 0; i < N; ++i) {
-  //   Log() << i << ": t: " << t(i) << ", alpha: " << alpha[i] << ", t/(s+t): " << t(i) / (s[i] + t(i)) << "\n";
-  // }
 
   for (auto& link : flowLinks) {
     if (sumLinkOutWeight[link.source] > 0) {
@@ -692,52 +571,16 @@ void FlowCalculator::calcUndirectedRegularizedFlow(const StateNetwork& network,
     nodeFlow[i] = (s[i] + t(i)) / (sum_s + sum_t);
   }
 
-  // enterFlow = nodeFlow;
-  // exitFlow = nodeFlow;
   nodeTeleportFlow.assign(numNodes, 0.0);
   for (unsigned int i = 0; i < N; ++i) {
     nodeTeleportFlow[i] = nodeFlow[i] * alpha[i];
   }
 
-  // double sumNodeRank = 1.0;
-  // double tmpN = 0.0;
-  // for (auto& flow : nodeFlow) {
-  //   tmpN += flow;
-  // }
-  // double tmpE = 0;
-  // Update the links with their global flow from the undirected PageRank values.
-  // Log() << "\nLink flow:\n";
   for (auto& link : flowLinks) {
     // TODO: Side effect from inflating alpha, need real alpha here.
     double beta = 1 - alpha[link.source] * (config.noSelfLinks ? 1 - nodeTeleportWeights[link.source] : 1);
     link.flow *= beta * nodeFlow[link.source] * 2;
-    // tmpE += link.flow;
-    // Double for non-loops to capture flow in both directions, assuming symmetric tele flow
-    // double teleFlow = nodeTeleportFlow[link.source] * nodeTeleportWeights[link.target] * (link.source == link.target ? 1 : 2);
-    // Log() << "  " << link.source << " - " << link.target << ": " << link.flow << " + " << teleFlow << " = " << (link.flow + teleFlow) << "\n";
   }
-
-  // Log() << "\nLink teleportation flow:\n";
-  // double sumLinkTeleFlow = 0.0;
-  // for (unsigned int i = 0; i < N; ++i) {
-  //   for (unsigned int j = i; j < N; ++j) {
-  //     if (i != j || config.noSelfLinks) {
-  //       sumLinkTeleFlow += nodeTeleportFlow[i] * nodeTeleportWeights[j] * (i == j ? 1 : 2);
-  //       // if (i < 5 && j < 5)
-  //       //   Log() << "  " << i << " - " << j << ": " << nodeTeleportFlow[i] * nodeTeleportWeights[j] * 2 << "\n";
-  //     }
-  //   }
-  // }
-  // Log() << "Sum link tele flow: " << sumLinkTeleFlow << "\n";
-
-  // Log() << "\nSum node flow: " << tmpN << ", sum link flow: " << tmpE << "\n\n";
-  // Log() << "Node flow (sum: " << tmpN << "):\n";
-  // for (unsigned int i = 0; i < N; ++i)
-  //   Log() << "  " << nodeFlow[i] << ", alpha: " << alpha[i] << ", t: " << t(i) << ", s: " << s[i] << ", k: " << k[i] << ", u: " << u(i) << "\n";
-  // Log() << "Link flow (sum: " << tmpE << " + tele: " << sumLinkTeleFlow << " = " << (tmpE + sumLinkTeleFlow) << "):\n";
-  // for (auto& link : flowLinks)
-  //   Log() << "  " << link.flow << ", ";
-  // Log() << "\n";
 }
 
 void FlowCalculator::calcDirectedBipartiteFlow(const StateNetwork& network, const Config& config) noexcept
@@ -794,7 +637,7 @@ void FlowCalculator::calcDirectedBipartiteFlow(const StateNetwork& network, cons
   double danglingRank;
 
   // Calculate two-step PageRank
-  const auto iteration = [&](const auto iteration, const double alpha, const double beta) {
+  const auto iteration = [&](const auto iter, const double alpha, const double beta) {
     danglingRank = 0.0;
     for (const auto& i : danglingIndices) {
       danglingRank += nodeFlow[i];
@@ -833,7 +676,7 @@ void FlowCalculator::calcDirectedBipartiteFlow(const StateNetwork& network, cons
 
     // Normalize if needed
     if (std::abs(nodeFlowDiff) > 1.0e-10) {
-      Log() << "(Normalizing ranks after " << iteration << " power iterations with error " << nodeFlowDiff << ") ";
+      Log() << "(Normalizing ranks after " << iter << " power iterations with error " << nodeFlowDiff << ") ";
       normalize(nodeFlow, nodeFlowDiff + 1.0);
     }
 
@@ -937,13 +780,7 @@ void FlowCalculator::finalize(StateNetwork& network, const Config& config, bool
       sumLinkFlow += linkData.flow;
     }
   }
-  // auto getDefaultTeleFlow = [nodeFlow, nodeOutDegree, config](unsigned int i) {
-  //   auto alpha = nodeOutDegree[i] == 0 ? 1 : config.teleportationProbability;
-  //   return alpha * nodeFlow[i];
-  // }
 
-  // Log() << "\nFinal node flow:\n";
-  double sumTeleFlow = 0.0;
   for (auto& nodeIt : network.m_nodes) {
     auto& node = nodeIt.second;
     const auto nodeIndex = nodeIndexMap[node.id];
@@ -957,7 +794,7 @@ void FlowCalculator::finalize(StateNetwork& network, const Config& config, bool
       // Remove self-teleportation flow
       node.enterFlow -= node.teleFlow * node.weight;
       node.exitFlow -= node.teleFlow * node.weight;
-      
+
       // Remove self-link flow
       unsigned int norm = config.isUndirectedFlow() ? 2 : 1;
       auto& outLinks = network.m_nodeLinkMap[node.id];
@@ -970,19 +807,11 @@ void FlowCalculator::finalize(StateNetwork& network, const Config& config, bool
         }
       }
     }
-    // if (config.isUndirectedFlow()) {
-    //   node.enterFlow *= 0.5;
-    //   node.exitFlow *= 0.5;
-    // }
-    sumNodeFlow += node.flow;
-    sumTeleFlow += node.teleFlow;
-    // Log() << "\nNode " << node.id << " (idx: " << nodeIndex << "): flow: " << node.flow << ", weight: " << node.weight << ", teleFlow: " << node.teleFlow << " (=> alpha: " << (node.teleFlow / node.flow) << ", adj: " << (node.teleFlow / node.flow * (1 - node.weight)) << ")"; //, enter + exit: " << (node.enterFlow + node.exitFlow) << ", ratio: " << (node.enterFlow + node.exitFlow) / node.flow;
-  }
-  // Log() << "\n";
 
+    sumNodeFlow += node.flow;
+  }
 
   // Enter/exit flow
-
   if (!config.isUndirectedClustering() && !config.regularized) {
     enterFlow.assign(N, 0);
     exitFlow.assign(N, 0);
@@ -1019,17 +848,6 @@ void FlowCalculator::finalize(StateNetwork& network, const Config& config, bool
   }
 
   Log() << "\n  => Sum node flow: " << sumNodeFlow << ", sum link flow: " << sumLinkFlow << "\n";
-
-
-  // Log() << "sumLinkWeight: " << sumLinkWeight << "\n";
-  // Log() << "Node flow:\n";
-  // for (auto& nodeIt : network.m_nodes) {
-  //   auto& node = nodeIt.second;
-  //   auto ind = nodeIndexMap[node.id];
-  //   auto k = nodeOutDegree[ind];
-  //   Log() << node.id << ":  " << node.flow << " (enter: " << node.enterFlow << ", exit: " << node.exitFlow << ", k: " << k << ")\n";
-  // }
-  // Log() << "\n";
 }
 
 } // namespace infomap
